# Copyright (c) 2023 Darren Erik Vengroff
"""Places in North Carolina."""


ABERDEEN_TOWN = "00160"
ADVANCE_CDP = "00440"
AHOSKIE_TOWN = "00500"
ALAMANCE_VILLAGE = "00640"
ALBEMARLE_CITY = "00680"
ALEXIS_CDP = "00880"
ALLIANCE_TOWN = "01000"
ALTAMAHAW_CDP = "01140"
ANDERSON_CREEK_CDP = "01340"
ANDREWS_TOWN = "01380"
ANGIER_TOWN = "01400"
ANSONVILLE_TOWN = "01420"
APEX_TOWN = "01520"
AQUADALE_CDP = "01560"
ARAPAHOE_TOWN = "01640"
ARCHDALE_CITY = "01720"
ARCHER_LODGE_TOWN = "01760"
ARROWHEAD_BEACH_CDP = "01972"
ASHEBORO_CITY = "02080"
ASHEVILLE_CITY = "02140"
ASHLEY_HEIGHTS_CDP = "02240"
ASKEWVILLE_TOWN = "02320"
ATKINSON_TOWN = "02460"
ATLANTIC_BEACH_TOWN = "02500"
ATLANTIC_CDP = "02480"
AULANDER_TOWN = "02580"
AURORA_TOWN = "02620"
AUTRYVILLE_TOWN = "02700"
AVERY_CREEK_CDP = "02760"
AVON_CDP = "02780"
AYDEN_TOWN = "02840"
BADIN_TOWN = "02960"
BAILEY_TOWN = "03020"
BAKERSVILLE_TOWN = "03100"
BALD_HEAD_ISLAND_VILLAGE = "03150"
BALFOUR_CDP = "03220"
BANNER_ELK_TOWN = "03500"
BARKER_HEIGHTS_CDP = "03640"
BARKER_TEN_MILE_CDP = "03665"
BARNARDSVILLE_CDP = "03720"
BATH_TOWN = "03840"
BAYBORO_TOWN = "03960"
BAYSHORE_CDP = "04015"
BAYVIEW_CDP = "04040"
BEAR_GRASS_TOWN = "04180"
BEAUFORT_TOWN = "04260"
BEECH_MOUNTAIN_TOWN = "04510"
BELHAVEN_TOWN = "04640"
BELL_ARTHUR_CDP = "04680"
BELMONT_CITY = "04840"
BELVILLE_TOWN = "04950"
BELVOIR_CDP = "04955"
BELWOOD_TOWN = "04960"
BENNETT_CDP = "05020"
BENSON_TOWN = "05040"
BENT_CREEK_CDP = "05049"
BERMUDA_RUN_TOWN = "05135"
BESSEMER_CITY_CITY = "05220"
BETHANIA_TOWN = "05340"
BETHEL_TOWN = "05460"
BETHLEHEM_CDP = "05530"
BEULAVILLE_TOWN = "05660"
BILTMORE_FOREST_TOWN = "05880"
BISCOE_TOWN = "06000"
BLACK_CREEK_TOWN = "06080"
BLACK_MOUNTAIN_TOWN = "06140"
BLADENBORO_TOWN = "06240"
BLOWING_ROCK_TOWN = "06500"
BLUE_CLAY_FARMS_CDP = "06510"
BOARDMAN_TOWN = "06660"
BOGUE_TOWN = "06740"
BOILING_SPRING_LAKES_CITY = "06760"
BOILING_SPRINGS_TOWN = "06800"
BOLIVIA_TOWN = "06820"
BOLTON_TOWN = "06860"
BONNETSVILLE_CDP = "06980"
BOONE_TOWN = "07080"
BOONVILLE_TOWN = "07140"
BOSTIC_TOWN = "07220"
BOWDENS_CDP = "07340"
BOWMORE_CDP = "07400"
BRANDYWINE_BAY_CDP = "07588"
BREVARD_CITY = "07720"
BRIAR_CHAPEL_CDP = "07748"
BRICES_CREEK_CDP = "07765"
BRIDGETON_TOWN = "07860"
BROAD_CREEK_CDP = "08040"
BROADWAY_TOWN = "08080"
BROGDEN_CDP = "08110"
BROOKFORD_TOWN = "08140"
BRUNSWICK_TOWN = "08420"
BRYSON_CITY_TOWN = "08480"
BUIES_CREEK_CDP = "08760"
BUNN_TOWN = "08860"
BUNNLEVEL_CDP = "08880"
BURGAW_TOWN = "08960"
BURLINGTON_CITY = "09060"
BURNSVILLE_TOWN = "09140"
BUTNER_TOWN = "09360"
BUTTERS_CDP = "09380"
BUXTON_CDP = "09400"
CAJAHS_MOUNTAIN_TOWN = "09530"
CALABASH_TOWN = "09540"
CALYPSO_TOWN = "09760"
CAMDEN_CDP = "09780"
CAMERON_TOWN = "09800"
CANDOR_TOWN = "10120"
CANTON_TOWN = "10240"
CAPE_CARTERET_TOWN = "10260"
CAPE_COLONY_CDP = "10264"
CAROLEEN_CDP = "10460"
CAROLINA_BEACH_TOWN = "10500"
CAROLINA_MEADOWS_CDP = "10532"
CAROLINA_SHORES_TOWN = "10550"
CARRBORO_TOWN = "10620"
CARTHAGE_TOWN = "10680"
CARY_TOWN = "10740"
CASAR_TOWN = "10760"
CASHIERS_CDP = "10800"
CASTALIA_TOWN = "10860"
CASTLE_HAYNE_CDP = "10880"
CASWELL_BEACH_TOWN = "10960"
CATAWBA_TOWN = "10980"
CEDAR_POINT_TOWN = "11340"
CEDAR_ROCK_VILLAGE = "11352"
CENTERVILLE_CDP = "11560"
CERRO_GORDO_TOWN = "11620"
CHADBOURN_TOWN = "11640"
CHAPEL_HILL_TOWN = "11800"
CHARLOTTE_CITY = "12000"
CHEROKEE_CDP = "12140"
CHERRY_BRANCH_CDP = "12186"
CHERRYVILLE_CITY = "12340"
CHIMNEY_ROCK_VILLAGE_VILLAGE = "12460"
CHINA_GROVE_TOWN = "12480"
CHINQUAPIN_CDP = "12520"
CHOCOWINITY_TOWN = "12580"
CHOWAN_BEACH_CDP = "12590"
CLAREMONT_CITY = "12720"
CLARKTON_TOWN = "12780"
CLAYTON_TOWN = "12860"
CLEMMONS_VILLAGE = "12960"
CLEVELAND_TOWN = "13000"
CLIFFSIDE_CDP = "13100"
CLINTON_CITY = "13240"
CLYDE_TOWN = "13280"
COATS_TOWN = "13360"
COFIELD_VILLAGE = "13460"
COINJOCK_CDP = "13500"
COLERAIN_TOWN = "13560"
COLUMBIA_TOWN = "13940"
COLUMBUS_TOWN = "13980"
COMO_TOWN = "14060"
CONCORD_CITY = "14100"
CONETOE_TOWN = "14200"
CONNELLY_SPRINGS_TOWN = "14280"
CONOVER_CITY = "14340"
CONWAY_TOWN = "14400"
COOLEEMEE_TOWN = "14460"
CORDOVA_CDP = "14600"
CORNELIUS_TOWN = "14700"
COVE_CITY_TOWN = "15020"
COVE_CREEK_CDP = "15040"
CRAMERTON_TOWN = "15260"
CREEDMOOR_CITY = "15320"
CRESWELL_TOWN = "15420"
CRICKET_CDP = "15440"
CROSSNORE_TOWN = "15580"
CROUSE_CDP = "15640"
CULLOWHEE_CDP = "15880"
CYPRESS_LANDING_CDP = "16084"
DALLAS_TOWN = "16180"
DANA_CDP = "16220"
DANBURY_TOWN = "16240"
DAVIDSON_TOWN = "16400"
DAVIS_CDP = "16480"
DEEP_RUN_CDP = "16720"
DEERCROFT_CDP = "16730"
DELCO_CDP = "16780"
DELLVIEW_TOWN = "16820"
DELWAY_CDP = "16860"
DENTON_TOWN = "16980"
DENVER_CDP = "17000"
DILLSBORO_TOWN = "17180"
DOBBINS_HEIGHTS_TOWN = "17325"
DOBSON_TOWN = "17340"
DORTCHES_TOWN = "17520"
DOVER_TOWN = "17660"
DREXEL_TOWN = "17860"
DUBLIN_TOWN = "18040"
DUCK_TOWN = "18060"
DUDLEY_CDP = "18080"
DUNDARRACH_CDP = "18300"
DUNN_CITY = "18320"
DURHAM_CITY = "19000"
EARL_TOWN = "19140"
EAST_ARCADIA_TOWN = "19300"
EAST_BEND_TOWN = "19320"
EAST_FLAT_ROCK_CDP = "19420"
EAST_LAURINBURG_TOWN = "19620"
EAST_ROCKINGHAM_CDP = "19800"
EAST_SPENCER_TOWN = "19860"
EASTOVER_TOWN = "19740"
EDEN_CITY = "20080"
EDENTON_TOWN = "20120"
EDNEYVILLE_CDP = "20280"
EFLAND_CDP = "20420"
ELIZABETH_CITY_CITY = "20580"
ELIZABETHTOWN_TOWN = "20600"
ELK_PARK_TOWN = "20700"
ELKIN_TOWN = "20620"
ELLENBORO_TOWN = "20780"
ELLERBE_TOWN = "20840"
ELM_CITY_TOWN = "20980"
ELON_TOWN = "21095"
ELROD_CDP = "21120"
ELROY_CDP = "21130"
EMERALD_ISLE_TOWN = "21160"
EMMA_CDP = "21260"
ENFIELD_TOWN = "21360"
ENGELHARD_CDP = "21380"
ENOCHVILLE_CDP = "21500"
ERWIN_TOWN = "21740"
ETOWAH_CDP = "21880"
EUREKA_TOWN = "21960"
EVERETTS_TOWN = "22040"
EVERGREEN_CDP = "22080"
FAIR_BLUFF_TOWN = "22240"
FAIRFIELD_CDP = "22280"
FAIRFIELD_HARBOUR_CDP = "22305"
FAIRMONT_TOWN = "22360"
FAIRPLAINS_CDP = "22380"
FAIRVIEW_CDP = "22440"
FAIRVIEW_TOWN = "22500"
FAISON_TOWN = "22560"
FAITH_TOWN = "22600"
FALCON_TOWN = "22620"
FALKLAND_TOWN = "22640"
FALLSTON_TOWN = "22720"
FARMINGTON_CDP = "22800"
FARMVILLE_TOWN = "22820"
FAYETTEVILLE_CITY = "22920"
FEARRINGTON_VILLAGE_CDP = "22982"
FIVE_POINTS_CDP = "23520"
FLAT_ROCK_CDP = "23640"
FLAT_ROCK_VILLAGE = "23600"
FLETCHER_TOWN = "23760"
FONTANA_DAM_TOWN = "23980"
FOREST_CITY_TOWN = "24080"
FOREST_HILLS_VILLAGE = "24170"
FOREST_OAKS_CDP = "24198"
FOSCOE_CDP = "24380"
FOUNTAIN_TOWN = "24440"
FOUR_OAKS_TOWN = "24520"
FOXFIRE_VILLAGE = "24570"
FRANKLIN_TOWN = "24640"
FRANKLINTON_TOWN = "24720"
FRANKLINVILLE_TOWN = "24740"
FREMONT_TOWN = "24900"
FRISCO_CDP = "25020"
FRUITLAND_CDP = "25160"
FUQUAY_VARINA_TOWN = "25300"
GAMEWELL_TOWN = "25380"
GARLAND_TOWN = "25460"
GARNER_TOWN = "25480"
GARYSBURG_TOWN = "25540"
GASTON_TOWN = "25560"
GASTONIA_CITY = "25580"
GATESVILLE_TOWN = "25680"
GERMANTON_CDP = "25880"
GERTON_CDP = "25900"
GIBSON_TOWN = "25940"
GIBSONVILLE_TOWN = "25980"
GLEN_ALPINE_TOWN = "26200"
GLEN_RAVEN_CDP = "26460"
GLENVILLE_CDP = "26520"
GLENWOOD_CDP = "26560"
GLOUCESTER_CDP = "26680"
GODWIN_TOWN = "26740"
GOLD_HILL_CDP = "26800"
GOLDSBORO_CITY = "26880"
GOLDSTON_TOWN = "26920"
GORMAN_CDP = "27120"
GOVERNORS_CLUB_CDP = "27180"
GOVERNORS_VILLAGE_CDP = "27182"
GRAHAM_CITY = "27280"
GRAINGERS_CDP = "27300"
GRANDFATHER_VILLAGE_VILLAGE = "27324"
GRANDY_CDP = "27400"
GRANITE_FALLS_TOWN = "27420"
GRANITE_QUARRY_TOWN = "27440"
GRANTSBORO_TOWN = "27520"
GREEN_LEVEL_TOWN = "27870"
GREENEVERS_TOWN = "27780"
GREENSBORO_CITY = "28000"
GREENVILLE_CITY = "28080"
GRIFTON_TOWN = "28200"
GRIMESLAND_TOWN = "28240"
GROVER_TOWN = "28400"
GULF_CDP = "28600"
HALF_MOON_CDP = "28900"
HALIFAX_TOWN = "28920"
HALLSBORO_CDP = "29000"
HAMILTON_TOWN = "29120"
HAMLET_CITY = "29160"
HAMPSTEAD_CDP = "29180"
HARKERS_ISLAND_CDP = "29560"
HARMONY_TOWN = "29640"
HARRELLS_TOWN = "29680"
HARRELLSVILLE_TOWN = "29720"
HARRISBURG_TOWN = "29800"
HASSELL_TOWN = "30040"
HATTERAS_CDP = "30100"
HAVELOCK_CITY = "30120"
HAW_RIVER_TOWN = "30260"
HAYESVILLE_TOWN = "30280"
HAYS_CDP = "30340"
HEMBY_BRIDGE_TOWN = "30620"
HENDERSON_CITY = "30660"
HENDERSONVILLE_CITY = "30720"
HENRIETTA_CDP = "30800"
HERTFORD_TOWN = "30900"
HICKORY_CITY = "31060"
HIDDENITE_CDP = "31260"
HIGH_POINT_CITY = "31400"
HIGH_SHOALS_CITY = "31440"
HIGHLANDS_TOWN = "31360"
HIGHTSVILLE_CDP = "31490"
HILDEBRAN_TOWN = "31500"
HILLSBOROUGH_TOWN = "31620"
HOBGOOD_TOWN = "31860"
HOBUCKEN_CDP = "31880"
HOFFMAN_TOWN = "31920"
HOLDEN_BEACH_TOWN = "31960"
HOLLISTER_CDP = "32100"
HOLLY_RIDGE_TOWN = "32180"
HOLLY_SPRINGS_TOWN = "32260"
HOOKERTON_TOWN = "32540"
HOOPERS_CREEK_CDP = "32580"
HOPE_MILLS_TOWN = "32640"
HORSE_SHOE_CDP = "32740"
HOT_SPRINGS_TOWN = "32840"
HUDSON_TOWN = "32980"
HUNTERSVILLE_TOWN = "33120"
ICARD_CDP = "33320"
INDIAN_BEACH_TOWN = "33460"
INDIAN_TRAIL_TOWN = "33560"
INGOLD_CDP = "33640"
IRON_STATION_CDP = "33820"
IVANHOE_CDP = "33940"
JAARS_CDP = "33993"
JACKSON_HEIGHTS_CDP = "34038"
JACKSON_SPRINGS_CDP = "34160"
JACKSON_TOWN = "34000"
JACKSONVILLE_CITY = "34200"
JAMES_CITY_CDP = "34260"
JAMESTOWN_TOWN = "34300"
JAMESVILLE_TOWN = "34320"
JEFFERSON_TOWN = "34440"
JONESVILLE_TOWN = "34840"
KANNAPOLIS_CITY = "35200"
KEENER_CDP = "35340"
KELFORD_TOWN = "35360"
KELLY_CDP = "35440"
KENANSVILLE_TOWN = "35460"
KENLY_TOWN = "35540"
KERNERSVILLE_TOWN = "35600"
KILL_DEVIL_HILLS_TOWN = "35720"
KING_CITY = "35760"
KINGS_GRANT_CDP = "35870"
KINGS_MOUNTAIN_CITY = "35880"
KINGSTOWN_TOWN = "35890"
KINSTON_CITY = "35920"
KITTRELL_TOWN = "36020"
KITTY_HAWK_TOWN = "36060"
KNIGHTDALE_TOWN = "36080"
KURE_BEACH_TOWN = "36220"
LA_GRANGE_TOWN = "36400"
LAKE_JUNALUSKA_CDP = "36480"
LAKE_LURE_TOWN = "36500"
LAKE_NORMAN_OF_CATAWBA_CDP = "36510"
LAKE_NORMAN_OF_IREDELL_CDP = "36511"
LAKE_PARK_VILLAGE = "36512"
LAKE_ROYALE_CDP = "36513"
LAKE_SANTEETLAH_TOWN = "36514"
LAKE_WACCAMAW_TOWN = "36640"
LANDIS_TOWN = "36860"
LANSING_TOWN = "36960"
LASKER_TOWN = "37000"
LATTIMORE_TOWN = "37040"
LAUREL_HILL_CDP = "37120"
LAUREL_PARK_TOWN = "37160"
LAURINBURG_CITY = "37220"
LAWNDALE_TOWN = "37260"
LEGGETT_TOWN = "37640"
LELAND_TOWN = "37680"
LENOIR_CITY = "37760"
LEWISTON_WOODVILLE_TOWN = "38030"
LEWISVILLE_TOWN = "38040"
LEXINGTON_CITY = "38060"
LIBERTY_TOWN = "38100"
LIGHT_OAK_CDP = "38170"
LILESVILLE_TOWN = "38200"
LILLINGTON_TOWN = "38220"
LINCOLNTON_CITY = "38320"
LINDEN_TOWN = "38360"
LINVILLE_CDP = "38420"
LITTLETON_TOWN = "38680"
LOCUST_CITY = "38860"
LONG_CREEK_CDP = "39060"
LONG_VIEW_TOWN = "39280"
LOUISBURG_TOWN = "39360"
LOVE_VALLEY_TOWN = "39420"
LOWELL_CITY = "39480"
LOWESVILLE_CDP = "39520"
LOWGAP_CDP = "39540"
LUCAMA_TOWN = "39600"
LUMBER_BRIDGE_TOWN = "39680"
LUMBERTON_CITY = "39700"
MACCLESFIELD_TOWN = "39960"
MACON_TOWN = "40540"
MADISON_TOWN = "40560"
MAGGIE_VALLEY_TOWN = "40600"
MAGNOLIA_TOWN = "40640"
MAIDEN_TOWN = "40660"
MAMERS_CDP = "40860"
MANNS_HARBOR_CDP = "40980"
MANTEO_TOWN = "41060"
MAR_MAC_CDP = "41540"
MARBLE_CDP = "41220"
MARIETTA_TOWN = "41380"
MARION_CITY = "41420"
MARS_HILL_TOWN = "41620"
MARSHALL_TOWN = "41580"
MARSHALLBERG_CDP = "41600"
MARSHVILLE_TOWN = "41640"
MARVIN_VILLAGE = "41720"
MATTHEWS_TOWN = "41960"
MAURY_CDP = "42000"
MAXTON_TOWN = "42020"
MAYODAN_TOWN = "42060"
MAYSVILLE_TOWN = "42100"
MCADENVILLE_TOWN = "39880"
MCDONALD_TOWN = "40140"
MCFARLAN_TOWN = "40240"
MCLEANSVILLE_CDP = "40460"
MEBANE_CITY = "42240"
MESIC_TOWN = "42480"
MICRO_TOWN = "42620"
MIDDLEBURG_TOWN = "42640"
MIDDLESEX_TOWN = "42700"
MIDLAND_TOWN = "42760"
MIDWAY_TOWN = "42860"
MILLERS_CREEK_CDP = "43160"
MILLINGPORT_CDP = "43200"
MILLS_RIVER_TOWN = "43260"
MILTON_TOWN = "43300"
MILWAUKEE_CDP = "43320"
MINERAL_SPRINGS_TOWN = "43360"
MINNESOTT_BEACH_TOWN = "43440"
MINT_HILL_TOWN = "43480"
MISENHEIMER_VILLAGE = "43580"
MOCKSVILLE_TOWN = "43720"
MOMEYER_TOWN = "43860"
MONCURE_CDP = "43880"
MONROE_CITY = "43920"
MONTREAT_TOWN = "44100"
MOORESBORO_TOWN = "44160"
MOORESVILLE_TOWN = "44220"
MORAVIAN_FALLS_CDP = "44280"
MOREHEAD_CITY_TOWN = "44320"
MORGANTON_CITY = "44400"
MORRISVILLE_TOWN = "44520"
MORVEN_TOWN = "44560"
MOUNT_AIRY_CITY = "44800"
MOUNT_GILEAD_TOWN = "44900"
MOUNT_HOLLY_CITY = "44960"
MOUNT_OLIVE_TOWN = "45100"
MOUNT_PLEASANT_TOWN = "45140"
MOUNTAIN_HOME_CDP = "44700"
MOUNTAIN_VIEW_CDP = "44770"
MOYOCK_CDP = "45460"
MULBERRY_CDP = "45560"
MURFREESBORO_TOWN = "45640"
MURPHY_TOWN = "45660"
MURRAYSVILLE_CDP = "45720"
MYRTLE_GROVE_CDP = "45840"
NAGS_HEAD_TOWN = "45880"
NASHVILLE_TOWN = "46000"
NAVASSA_TOWN = "46060"
NEBO_CDP = "46100"
NEUSE_FOREST_CDP = "46280"
NEW_BERN_CITY = "46340"
NEW_HOPE_CDP = "46650"
NEW_LONDON_TOWN = "46820"
NEWLAND_TOWN = "46740"
NEWPORT_TOWN = "46860"
NEWTON_GROVE_TOWN = "47020"
NEWTON_CITY = "47000"
NORLINA_TOWN = "47240"
NORMAN_TOWN = "47260"
NORTH_TOPSAIL_BEACH_TOWN = "47845"
NORTH_WILKESBORO_TOWN = "47880"
NORTHCHASE_CDP = "47485"
NORTHLAKES_CDP = "47695"
NORTHWEST_CITY = "47860"
NORWOOD_TOWN = "47980"
OAK_CITY_TOWN = "48060"
OAK_ISLAND_TOWN = "48345"
OAK_RIDGE_TOWN = "48480"
OAKBORO_TOWN = "48040"
OCEAN_ISLE_BEACH_TOWN = "48700"
OCRACOKE_CDP = "48740"
OGDEN_CDP = "48790"
OLD_FORT_TOWN = "48920"
OLD_HUNDRED_CDP = "48940"
ORIENTAL_TOWN = "49380"
ORRUM_TOWN = "49460"
OSSIPEE_TOWN = "49600"
OXFORD_CITY = "49800"
PANTEGO_TOWN = "50080"
PARKTON_TOWN = "50340"
PARMELE_TOWN = "50540"
PATTERSON_SPRINGS_TOWN = "50700"
PEACHLAND_TOWN = "50820"
PELETIER_TOWN = "51040"
PEMBROKE_TOWN = "51080"
PIKEVILLE_TOWN = "51780"
PILOT_MOUNTAIN_TOWN = "51820"
PINE_KNOLL_SHORES_TOWN = "52000"
PINE_LEVEL_TOWN = "52020"
PINEBLUFF_TOWN = "51840"
PINEHURST_VILLAGE = "51940"
PINETOPS_TOWN = "52140"
PINETOWN_CDP = "52160"
PINEVILLE_TOWN = "52220"
PINEY_GREEN_CDP = "52260"
PINK_HILL_TOWN = "52400"
PINNACLE_CDP = "52500"
PITTSBORO_TOWN = "52660"
PLAIN_VIEW_CDP = "52685"
PLEASANT_GARDEN_TOWN = "52760"
PLEASANT_HILL_CDP = "52920"
PLYMOUTH_TOWN = "53040"
POLKTON_TOWN = "53140"
POLKVILLE_CITY = "53160"
POLLOCKSVILLE_TOWN = "53200"
PORTERS_NECK_CDP = "53475"
POTTERS_HILL_CDP = "53580"
POWELLSVILLE_TOWN = "53680"
PRINCETON_TOWN = "53820"
PRINCEVILLE_TOWN = "53840"
PROCTORVILLE_TOWN = "53900"
PROSPECT_CDP = "53950"
PUMPKIN_CENTER_CDP = "54160"
RAEFORD_CITY = "54580"
RAEMON_CDP = "54600"
RALEIGH_CITY = "55000"
RAMSEUR_TOWN = "55040"
RANDLEMAN_CITY = "55080"
RANLO_TOWN = "55260"
RAYNHAM_TOWN = "55340"
RED_CROSS_TOWN = "55460"
RED_OAK_TOWN = "55640"
RED_SPRINGS_TOWN = "55660"
REIDSVILLE_CITY = "55900"
RENNERT_TOWN = "55940"
REX_CDP = "56100"
RHODHISS_TOWN = "56240"
RICH_SQUARE_TOWN = "56440"
RICHFIELD_TOWN = "56340"
RICHLANDS_TOWN = "56360"
RIEGELWOOD_CDP = "56600"
RIVER_BEND_TOWN = "56710"
RIVER_ROAD_CDP = "56815"
ROANOKE_RAPIDS_CITY = "56900"
ROBBINS_TOWN = "57000"
ROBBINSVILLE_TOWN = "57020"
ROBERDEL_CDP = "57039"
ROBERSONVILLE_TOWN = "57100"
ROCKFISH_CDP = "57200"
ROCKINGHAM_CITY = "57260"
ROCKWELL_TOWN = "57340"
ROCKY_MOUNT_CITY = "57500"
ROCKY_POINT_CDP = "57540"
RODANTHE_CDP = "57580"
ROLESVILLE_TOWN = "57640"
RONDA_TOWN = "57700"
ROPER_TOWN = "57740"
ROSE_HILL_TOWN = "57860"
ROSEBORO_TOWN = "57800"
ROSMAN_TOWN = "58020"
ROUGEMONT_CDP = "58040"
ROWLAND_TOWN = "58140"
ROXBORO_CITY = "58160"
ROXOBEL_TOWN = "58180"
ROYAL_PINES_CDP = "58260"
RUFFIN_CDP = "58340"
RURAL_HALL_TOWN = "58360"
RUTH_TOWN = "58420"
RUTHERFORD_COLLEGE_TOWN = "58440"
RUTHERFORDTON_TOWN = "58460"
SALEM_CDP = "58740"
SALEMBURG_TOWN = "58840"
SALISBURY_CITY = "58860"
SALUDA_CITY = "58920"
SALVO_CDP = "58940"
SANDY_CREEK_TOWN = "59090"
SANDYFIELD_TOWN = "59135"
SANFORD_CITY = "59280"
SARATOGA_TOWN = "59340"
SAWMILLS_TOWN = "59540"
SAXAPAHAW_CDP = "59580"
SCOTCH_MEADOWS_CDP = "59765"
SCOTLAND_NECK_TOWN = "59780"
SEA_BREEZE_CDP = "60000"
SEABOARD_TOWN = "59980"
SEAGROVE_TOWN = "60080"
SEDALIA_TOWN = "60180"
SELMA_TOWN = "60320"
SEVEN_DEVILS_TOWN = "60505"
SEVEN_LAKES_CDP = "60515"
SEVEN_SPRINGS_TOWN = "60540"
SEVERN_TOWN = "60560"
SHALLOTTE_TOWN = "60800"
SHANNON_CDP = "60940"
SHARPSBURG_TOWN = "61060"
SHELBY_CITY = "61200"
SILER_CITY_TOWN = "61860"
SILVER_CITY_CDP = "61920"
SILVER_LAKE_CDP = "61950"
SIMPSON_VILLAGE = "62040"
SIMS_TOWN = "62060"
SKIPPERS_CORNER_CDP = "62190"
SMITHFIELD_TOWN = "62520"
SMITHTOWN_CDP = "62580"
SNEADS_FERRY_CDP = "62680"
SNOW_HILL_TOWN = "62760"
SOUTH_HENDERSON_CDP = "63240"
SOUTH_MILLS_CDP = "63340"
SOUTH_ROSEMARY_CDP = "63470"
SOUTH_WELDON_CDP = "63560"
SOUTHERN_PINES_TOWN = "63120"
SOUTHERN_SHORES_TOWN = "63130"
SOUTHMONT_CDP = "63360"
SOUTHPORT_CITY = "63400"
SPARTA_TOWN = "63680"
SPEED_TOWN = "63720"
SPENCER_MOUNTAIN_TOWN = "63780"
SPENCER_TOWN = "63760"
SPINDALE_TOWN = "63880"
SPIVEYS_CORNER_CDP = "63920"
SPOUT_SPRINGS_CDP = "64000"
SPRING_HOPE_TOWN = "64160"
SPRING_LAKE_TOWN = "64180"
SPRINGDALE_CDP = "64050"
SPRUCE_PINE_TOWN = "64260"
ST_HELENA_VILLAGE = "58620"
ST_JAMES_TOWN = "58630"
ST_PAULS_TOWN = "58720"
ST_STEPHENS_CDP = "58730"
STALEY_TOWN = "64380"
STALLINGS_TOWN = "64420"
STANFIELD_TOWN = "64460"
STANLEY_TOWN = "64500"
STANTONSBURG_TOWN = "64560"
STAR_TOWN = "64580"
STATESVILLE_CITY = "64740"
STEDMAN_TOWN = "64840"
STEM_TOWN = "64940"
STOKES_CDP = "65020"
STOKESDALE_TOWN = "65040"
STONEVILLE_TOWN = "65100"
STONEWALL_TOWN = "65120"
STONY_POINT_CDP = "65260"
STOVALL_TOWN = "65320"
SUGAR_MOUNTAIN_VILLAGE = "65530"
SUMMERFIELD_TOWN = "65580"
SUNBURY_CDP = "65700"
SUNSET_BEACH_TOWN = "65900"
SURF_CITY_TOWN = "66040"
SWAN_QUARTER_CDP = "66340"
SWANNANOA_CDP = "66280"
SWANSBORO_TOWN = "66360"
SWEPSONVILLE_TOWN = "66460"
SYLVA_TOWN = "66500"
TABOR_CITY_TOWN = "66520"
TAR_HEEL_TOWN = "66740"
TARBORO_TOWN = "66700"
TAYLORSVILLE_TOWN = "66960"
TAYLORTOWN_TOWN = "66980"
TEACHEY_TOWN = "67000"
THOMASVILLE_CITY = "67420"
TOAST_CDP = "67700"
TOBACCOVILLE_VILLAGE = "67720"
TOPSAIL_BEACH_TOWN = "68040"
TRENT_WOODS_TOWN = "68340"
TRENTON_TOWN = "68320"
TRINITY_CITY = "68400"
TROUTMAN_TOWN = "68500"
TROY_TOWN = "68520"
TRYON_TOWN = "68580"
TURKEY_TOWN = "68740"
TYRO_CDP = "69020"
UNIONVILLE_TOWN = "69260"
VALDESE_TOWN = "69520"
VALLE_CRUCIS_CDP = "69600"
VALLEY_HILL_CDP = "69640"
VANCEBORO_TOWN = "69680"
VANDEMERE_TOWN = "69720"
VANDER_CDP = "69740"
VANN_CROSSROADS_CDP = "69755"
VARNAMTOWN_TOWN = "69795"
VASS_TOWN = "69840"
WACO_TOWN = "70320"
WADE_TOWN = "70340"
WADESBORO_TOWN = "70380"
WAGRAM_TOWN = "70480"
WAKE_FOREST_TOWN = "70540"
WAKULLA_CDP = "70580"
WALKERTOWN_TOWN = "70660"
WALLACE_TOWN = "70720"
WALLBURG_TOWN = "70740"
WALNUT_COVE_TOWN = "70780"
WALNUT_CREEK_VILLAGE = "70820"
WALSTONBURG_TOWN = "70860"
WANCHESE_CDP = "70920"
WARRENTON_TOWN = "71100"
WARSAW_TOWN = "71160"
WASHINGTON_PARK_TOWN = "71240"
WASHINGTON_CITY = "71220"
WATHA_TOWN = "71320"
WAVES_CDP = "71440"
WAXHAW_TOWN = "71460"
WAYNESVILLE_TOWN = "71500"
WEAVERVILLE_TOWN = "71560"
WEBSTER_TOWN = "71600"
WEDDINGTON_TOWN = "71680"
WELCOME_CDP = "71760"
WELDON_TOWN = "71780"
WENDELL_TOWN = "71860"
WENTWORTH_TOWN = "71900"
WESLEY_CHAPEL_VILLAGE = "71940"
WEST_CANTON_CDP = "72150"
WEST_JEFFERSON_TOWN = "72540"
WEST_MARION_CDP = "72600"
WESTPORT_CDP = "72755"
WHISPERING_PINES_VILLAGE = "73140"
WHITAKERS_TOWN = "73160"
WHITE_LAKE_TOWN = "73300"
WHITE_OAK_CDP = "73320"
WHITE_PLAINS_CDP = "73460"
WHITEVILLE_CITY = "73660"
WHITSETT_TOWN = "73760"
WHITTIER_CDP = "73780"
WILKESBORO_TOWN = "74020"
WILLIAMSTON_TOWN = "74220"
WILMINGTON_CITY = "74440"
WILSON_CITY = "74540"
WILSONS_MILLS_TOWN = "74580"
WINDSOR_TOWN = "74680"
WINFALL_TOWN = "74720"
WINGATE_TOWN = "74760"
WINSTON_SALEM_CITY = "75000"
WINTERVILLE_TOWN = "75060"
WINTON_TOWN = "75080"
WOODFIN_TOWN = "75280"
WOODLAND_TOWN = "75340"
WOODLAWN_CDP = "75375"
WRIGHTSBORO_CDP = "75780"
WRIGHTSVILLE_BEACH_TOWN = "75820"
YADKIN_COLLEGE_CDP = "75880"
YADKINVILLE_TOWN = "75960"
YANCEYVILLE_TOWN = "76000"
YOUNGSVILLE_TOWN = "76200"
ZEBULON_TOWN = "76220"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in West Virginia."""


BARBOUR = "001"
BERKELEY = "003"
BOONE = "005"
BRAXTON = "007"
BROOKE = "009"
CABELL = "011"
CALHOUN = "013"
CLAY = "015"
DODDRIDGE = "017"
FAYETTE = "019"
GILMER = "021"
GRANT = "023"
GREENBRIER = "025"
HAMPSHIRE = "027"
HANCOCK = "029"
HARDY = "031"
HARRISON = "033"
JACKSON = "035"
JEFFERSON = "037"
KANAWHA = "039"
LEWIS = "041"
LINCOLN = "043"
LOGAN = "045"
MARION = "049"
MARSHALL = "051"
MASON = "053"
MCDOWELL = "047"
MERCER = "055"
MINERAL = "057"
MINGO = "059"
MONONGALIA = "061"
MONROE = "063"
MORGAN = "065"
NICHOLAS = "067"
OHIO = "069"
PENDLETON = "071"
PLEASANTS = "073"
POCAHONTAS = "075"
PRESTON = "077"
PUTNAM = "079"
RALEIGH = "081"
RANDOLPH = "083"
RITCHIE = "085"
ROANE = "087"
SUMMERS = "089"
TAYLOR = "091"
TUCKER = "093"
TYLER = "095"
UPSHUR = "097"
WAYNE = "099"
WEBSTER = "101"
WETZEL = "103"
WIRT = "105"
WOOD = "107"
WYOMING = "109"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New Jersey."""


ABSECON_HIGHLANDS_CDP = "00160"
ABSECON_CITY = "00100"
ALLAMUCHY_CDP = "00640"
ALLENDALE_BOROUGH = "00700"
ALLENHURST_BOROUGH = "00730"
ALLENTOWN_BOROUGH = "00760"
ALLENWOOD_CDP = "00790"
ALLOWAY_CDP = "00850"
ALPHA_BOROUGH = "01030"
ALPINE_BOROUGH = "01090"
AMPERE_NORTH_CDP = "01184"
ANDERSON_CDP = "01300"
ANDOVER_BOROUGH = "01330"
ANNANDALE_CDP = "01480"
ARROWHEAD_LAKE_CDP = "01825"
ASBURY_CDP = "01900"
ASBURY_PARK_CITY = "01960"
ASHLAND_CDP = "01990"
ATCO_CDP = "02020"
ATLANTIC_CITY_CITY = "02080"
ATLANTIC_HIGHLANDS_BOROUGH = "02110"
AUBURN_CDP = "02170"
AUDUBON_PARK_BOROUGH = "02230"
AUDUBON_BOROUGH = "02200"
AVALON_BOROUGH = "02320"
AVENEL_CDP = "02350"
AVON_BY_THE_SEA_BOROUGH = "02440"
BARCLAY_CDP = "02880"
BARGAINTOWN_CDP = "02920"
BARNEGAT_CDP = "03040"
BARNEGAT_LIGHT_BOROUGH = "03130"
BARRINGTON_BOROUGH = "03250"
BASKING_RIDGE_CDP = "03340"
BAY_HEAD_BOROUGH = "03520"
BAYONNE_CITY = "03580"
BEACH_HAVEN_WEST_CDP = "04120"
BEACH_HAVEN_BOROUGH = "03940"
BEACHWOOD_BOROUGH = "04180"
BEATTYSTOWN_CDP = "04252"
BECKETT_CDP = "04400"
BEDMINSTER_CDP = "04420"
BEESLEYS_POINT_CDP = "04540"
BELFORD_CDP = "04600"
BELLE_MEAD_CDP = "04630"
BELLEPLAIN_CDP = "04660"
BELLMAWR_BOROUGH = "04750"
BELMAR_BOROUGH = "04930"
BELVIDERE_TOWN = "04990"
BERGENFIELD_BOROUGH = "05170"
BERLIN_BOROUGH = "05440"
BERNARDSVILLE_BOROUGH = "05590"
BEVERLY_CITY = "05740"
BLACKWELLS_MILLS_CDP = "06025"
BLACKWOOD_CDP = "06040"
BLAIRSTOWN_CDP = "06130"
BLAWENBURG_CDP = "06190"
BLOOMINGDALE_BOROUGH = "06340"
BLOOMSBURY_BOROUGH = "06370"
BOGOTA_BOROUGH = "06490"
BOONTON_TOWN = "06610"
BORDENTOWN_CITY = "06670"
BOUND_BROOK_BOROUGH = "06790"
BRADLEY_BEACH_BOROUGH = "06970"
BRADLEY_GARDENS_CDP = "07000"
BRAINARDS_CDP = "07120"
BRANCHVILLE_BOROUGH = "07300"
BRASS_CASTLE_CDP = "07360"
BRIDGEPORT_CDP = "07570"
BRIDGETON_CITY = "07600"
BRIDGEVILLE_CDP = "07660"
BRIDGEWATER_CENTER_CDP = "07728"
BRIELLE_BOROUGH = "07750"
BRIGANTINE_CITY = "07810"
BROADWAY_CDP = "08020"
BROOKDALE_CDP = "08110"
BROOKFIELD_CDP = "08140"
BROOKLAWN_BOROUGH = "08170"
BROOKSIDE_CDP = "08260"
BROWNS_MILLS_CDP = "08455"
BROWNVILLE_CDP = "08492"
BUDD_LAKE_CDP = "08620"
BUENA_BOROUGH = "08680"
BURLEIGH_CDP = "08890"
BURLINGTON_CITY = "08920"
BUTLER_BOROUGH = "09040"
BUTTZVILLE_CDP = "09100"
BYRAM_CENTER_CDP = "09170"
CALDWELL_BOROUGH = "09250"
CALIFON_BOROUGH = "09280"
CAMDEN_CITY = "10000"
CAPE_MAY_COURT_HOUSE_CDP = "10300"
CAPE_MAY_POINT_BOROUGH = "10330"
CAPE_MAY_CITY = "10270"
CARLLS_CORNER_CDP = "10450"
CARLSTADT_BOROUGH = "10480"
CARNEYS_POINT_CDP = "10600"
CARTERET_BOROUGH = "10750"
CEDAR_GLEN_LAKES_CDP = "11140"
CEDAR_GLEN_WEST_CDP = "11155"
CEDAR_KNOLLS_CDP = "11290"
CEDARVILLE_CDP = "11410"
CENTRE_GROVE_CDP = "11770"
CHATHAM_BOROUGH = "12100"
CHERRY_HILL_MALL_CDP = "12385"
CHESILHURST_BOROUGH = "12550"
CHESTER_BOROUGH = "12580"
CLAYTON_BOROUGH = "13360"
CLEARBROOK_CDP = "13395"
CLEMENTON_BOROUGH = "13420"
CLIFFSIDE_PARK_BOROUGH = "13570"
CLIFFWOOD_BEACH_CDP = "13630"
CLIFTON_CITY = "13690"
CLINTON_TOWN = "13720"
CLOSTER_BOROUGH = "13810"
CLYDE_CDP = "13990"
COLLINGS_LAKES_CDP = "14230"
COLLINGSWOOD_BOROUGH = "14260"
COLOGNE_CDP = "14350"
COLONIA_CDP = "14380"
COLUMBIA_CDP = "14590"
CONCORDIA_CDP = "14758"
CONNECTICUT_FARMS_CDP = "14815"
COOKSTOWN_CDP = "14980"
CORBIN_CITY_CITY = "15160"
COUNTRY_LAKE_ESTATES_CDP = "15250"
CRANBURY_CDP = "15520"
CRANDON_LAKES_CDP = "15610"
CRANFORD_CDP = "15638"
CREAM_RIDGE_CDP = "15730"
CRESSKILL_BOROUGH = "15820"
CRESTWOOD_VILLAGE_CDP = "15910"
CROSSWICKS_CDP = "16060"
CUMBERLAND_HESSTOWN_CDP = "16278"
DAYTON_CDP = "16630"
DEAL_BOROUGH = "16660"
DEANS_CDP = "16720"
DEERFIELD_STREET_CDP = "16960"
DELAWARE_CDP = "17200"
DELAWARE_PARK_CDP = "17260"
DELMONT_CDP = "17410"
DEMAREST_BOROUGH = "17530"
DENNISVILLE_CDP = "17590"
DIAMOND_BEACH_CDP = "17815"
DIVIDING_CREEK_CDP = "17890"
DORCHESTER_CDP = "18010"
DOROTHY_CDP = "18040"
DOVER_BEACHES_NORTH_CDP = "18148"
DOVER_BEACHES_SOUTH_CDP = "18151"
DOVER_TOWN = "18070"
DUMONT_BOROUGH = "18400"
DUNELLEN_BOROUGH = "18490"
DUTCH_NECK_CDP = "18632"
EAST_FRANKLIN_CDP = "19130"
EAST_FREEHOLD_CDP = "19150"
EAST_MILLSTONE_CDP = "19330"
EAST_NEWARK_BOROUGH = "19360"
EAST_ORANGE_CITY = "19390"
EAST_ROCKY_HILL_CDP = "19490"
EAST_RUTHERFORD_BOROUGH = "19510"
EAST_VINELAND_CDP = "19690"
EATONTOWN_BOROUGH = "19840"
ECHELON_CDP = "19900"
EDGEWATER_BOROUGH = "20020"
EGG_HARBOR_CITY_CITY = "20350"
ELIZABETH_CITY = "21000"
ELLISBURG_CDP = "21120"
ELMER_BOROUGH = "21240"
ELMWOOD_PARK_BOROUGH = "21300"
ELWOOD_CDP = "21420"
EMERSON_BOROUGH = "21450"
ENCORE_AT_MONROE_CDP = "21473"
ENGLEWOOD_CLIFFS_BOROUGH = "21510"
ENGLEWOOD_CITY = "21480"
ENGLISH_CREEK_CDP = "21540"
ENGLISHTOWN_BOROUGH = "21570"
ERMA_CDP = "21660"
ESSEX_FELLS_BOROUGH = "21840"
ESTELL_MANOR_CITY = "21870"
FAIR_HAVEN_BOROUGH = "22440"
FAIR_LAWN_BOROUGH = "22470"
FAIRTON_CDP = "22530"
FAIRVIEW_CDP = "22740"
FAIRVIEW_BOROUGH = "22560"
FANWOOD_BOROUGH = "22860"
FAR_HILLS_BOROUGH = "22890"
FARMINGDALE_BOROUGH = "22950"
FIELDSBORO_BOROUGH = "23250"
FINDERNE_CDP = "23310"
FINESVILLE_CDP = "23340"
FLAGTOWN_CDP = "23610"
FLANDERS_CDP = "23640"
FLEMINGTON_BOROUGH = "23700"
FLORENCE_CDP = "23820"
FLORHAM_PARK_BOROUGH = "23910"
FOLSOM_BOROUGH = "23940"
FORDS_CDP = "24030"
FORKED_RIVER_CDP = "24180"
FORSGATE_CDP = "24285"
FORT_DIX_CDP = "24300"
FORT_LEE_BOROUGH = "24420"
FORTESCUE_CDP = "24360"
FRANKLIN_CENTER_CDP = "24965"
FRANKLIN_LAKES_BOROUGH = "24990"
FRANKLIN_PARK_CDP = "25020"
FRANKLIN_BOROUGH = "24930"
FRANKLINVILLE_CDP = "25050"
FREEHOLD_BOROUGH = "25200"
FRENCHTOWN_BOROUGH = "25350"
GANDYS_BEACH_CDP = "25590"
GARFIELD_CITY = "25770"
GARWOOD_BOROUGH = "25800"
GERMANIA_CDP = "26010"
GIBBSBORO_BOROUGH = "26070"
GIBBSTOWN_CDP = "26100"
GILLETTE_CDP = "26220"
GLASSBORO_BOROUGH = "26340"
GLEN_GARDNER_BOROUGH = "26550"
GLEN_RIDGE_BOROUGH = "26610"
GLEN_ROCK_BOROUGH = "26640"
GLENDORA_CDP = "26520"
GLOUCESTER_CITY_CITY = "26820"
GOLDEN_TRIANGLE_CDP = "26902"
GOSHEN_CDP = "27030"
GOULDTOWN_CDP = "27060"
GREAT_MEADOWS_CDP = "27360"
GREAT_NOTCH_CDP = "27390"
GREEN_KNOLL_CDP = "27840"
GREEN_VILLAGE_CDP = "28020"
GREENTREE_CDP = "27995"
GREENWICH_CDP_CUMBERLAND_COUNTY = "28140"
GREENWICH_CDP_WARREN_COUNTY = "28250"
GRENLOCH_CDP = "28380"
GRIGGSTOWN_CDP = "28470"
GROVEVILLE_CDP = "28620"
GUTTENBERG_TOWN = "28650"
HACKENSACK_CITY = "28680"
HACKETTSTOWN_TOWN = "28710"
HADDON_HEIGHTS_BOROUGH = "28800"
HADDONFIELD_BOROUGH = "28770"
HAINESBURG_CDP = "28920"
HALEDON_BOROUGH = "29070"
HAMBURG_BOROUGH = "29220"
HAMILTON_SQUARE_CDP = "29370"
HAMMONTON_TOWN = "29430"
HAMPTON_BOROUGH = "29460"
HANCOCKS_BRIDGE_CDP = "29520"
HARLINGEN_CDP = "29940"
HARMONY_CDP = "30060"
HARRINGTON_PARK_BOROUGH = "30150"
HARRISON_TOWN = "30210"
HARRISONVILLE_CDP = "30270"
HARVEY_CEDARS_BOROUGH = "30390"
HASBROUCK_HEIGHTS_BOROUGH = "30420"
HAWORTH_BOROUGH = "30540"
HAWTHORNE_BOROUGH = "30570"
HEATHCOTE_CDP = "30738"
HEISLERVILLE_CDP = "30810"
HELMETTA_BOROUGH = "30840"
HEWITT_CDP = "31110"
HI_NELLA_BOROUGH = "32220"
HIBERNIA_CDP = "31170"
HIGH_BRIDGE_BOROUGH = "31320"
HIGHLAND_LAKES_CDP = "31410"
HIGHLAND_PARK_BOROUGH = "31470"
HIGHLANDS_BOROUGH = "31500"
HIGHTSTOWN_BOROUGH = "31620"
HILLSBOROUGH_CDP = "31880"
HILLSDALE_BOROUGH = "31920"
HO_HO_KUS_BOROUGH = "32310"
HOBOKEN_CITY = "32250"
HOLIDAY_CITY_SOUTH_CDP = "32418"
HOLIDAY_CITY_BERKELEY_CDP = "32415"
HOLIDAY_HEIGHTS_CDP = "32424"
HOPATCONG_BOROUGH = "32910"
HOPE_CDP = "33030"
HOPELAWN_CDP = "33090"
HOPEWELL_BOROUGH = "33150"
HUTCHINSON_CDP = "33690"
INTERLAKEN_BOROUGH = "34200"
ISELIN_CDP = "34470"
ISLAND_HEIGHTS_BOROUGH = "34530"
JAMESBURG_BOROUGH = "34890"
JERSEY_CITY_CITY = "36000"
JOBSTOWN_CDP = "36120"
JOHNSONBURG_CDP = "36150"
JULIUSTOWN_CDP = "36300"
KEAN_UNIVERSITY_CDP = "36484"
KEANSBURG_BOROUGH = "36480"
KEARNY_TOWN = "36510"
KEASBEY_CDP = "36570"
KENDALL_PARK_CDP = "36660"
KENILWORTH_BOROUGH = "36690"
KENVIL_CDP = "36720"
KEYPORT_BOROUGH = "36810"
KINGSTON_CDP = "36930"
KINGSTON_ESTATES_CDP = "36960"
KINNELON_BOROUGH = "37110"
LAKE_COMO_BOROUGH = "37560"
LAKE_HIAWATHA_CDP = "37680"
LAKE_HOPATCONG_CDP = "37710"
LAKE_MOHAWK_CDP = "38040"
LAKE_TELEMARK_CDP = "38430"
LAKEHURST_BOROUGH = "37770"
LAKESIDE_BEEBE_RUN_CDP = "38296"
LAKEWOOD_CDP = "38580"
LAMBERTVILLE_CITY = "38610"
LAMINGTON_CDP = "38670"
LANDING_CDP = "38700"
LAUREL_HEIGHTS_CDP = "39045"
LAUREL_LAKE_CDP = "39120"
LAUREL_SPRINGS_BOROUGH = "39210"
LAURENCE_HARBOR_CDP = "39360"
LAVALLETTE_BOROUGH = "39390"
LAWNSIDE_BOROUGH = "39420"
LAWRENCEVILLE_CDP = "39570"
LAYTON_CDP = "39600"
LEBANON_BOROUGH = "39630"
LEDGEWOOD_CDP = "39750"
LEEDS_POINT_CDP = "39810"
LEESBURG_CDP = "39870"
LEISURE_KNOLL_CDP = "39883"
LEISURE_VILLAGE_CDP = "39900"
LEISURE_VILLAGE_EAST_CDP = "39910"
LEISURE_VILLAGE_WEST_CDP = "39916"
LEISURETOWNE_CDP = "39885"
LEONARDO_CDP = "39990"
LEONIA_BOROUGH = "40020"
LIBERTY_CORNER_CDP = "40140"
LINCOLN_PARK_BOROUGH = "40290"
LINCROFT_CDP = "40320"
LINDEN_CITY = "40350"
LINDENWOLD_BOROUGH = "40440"
LINWOOD_CITY = "40530"
LITTLE_FERRY_BOROUGH = "40680"
LITTLE_SILVER_BOROUGH = "40770"
LLEWELLYN_PARK_CDP = "40990"
LOCH_ARBOUR_VILLAGE = "41010"
LODI_BOROUGH = "41100"
LONG_BRANCH_CITY = "41310"
LONG_VALLEY_CDP = "41400"
LONGPORT_BOROUGH = "41370"
LOPATCONG_OVERLOOK_CDP = "41495"
LOWER_BERKSHIRE_VALLEY_CDP = "41700"
LYONS_CDP = "42180"
MACOPIN_CDP = "42450"
MADISON_PARK_CDP = "42540"
MADISON_BOROUGH = "42510"
MAGNOLIA_BOROUGH = "42630"
MALAGA_CDP = "42840"
MANAHAWKIN_CDP = "42930"
MANASQUAN_BOROUGH = "43050"
MANTOLOKING_BOROUGH = "43380"
MANVILLE_BOROUGH = "43620"
MARGATE_CITY_CITY = "43890"
MARKSBORO_CDP = "43980"
MARLBORO_CDP = "44010"
MARLTON_CDP = "44100"
MARMORA_CDP = "44280"
MARSHALLVILLE_CDP = "44345"
MARTINSVILLE_CDP = "44430"
MATAWAN_BOROUGH = "44520"
MAURICETOWN_CDP = "44670"
MAYS_LANDING_CDP = "44820"
MAYWOOD_BOROUGH = "44880"
MCGUIRE_AFB_CDP = "42390"
MCKEE_CITY_CDP = "42420"
MEDFORD_LAKES_BOROUGH = "45210"
MENDHAM_BOROUGH = "45330"
MENLO_PARK_TERRACE_CDP = "45450"
MERCERVILLE_CDP = "45480"
MERCHANTVILLE_BOROUGH = "45510"
METUCHEN_BOROUGH = "45690"
MICKLETON_CDP = "45780"
MIDDLEBUSH_CDP = "45870"
MIDDLESEX_BOROUGH = "45900"
MIDLAND_PARK_BOROUGH = "46110"
MILFORD_BOROUGH = "46260"
MILLINGTON_CDP = "46470"
MILLSTONE_BOROUGH = "46590"
MILLTOWN_BOROUGH = "46620"
MILLVILLE_CITY = "46680"
MILMAY_CDP = "46710"
MIZPAH_CDP = "46980"
MONEY_ISLAND_CDP = "47006"
MONMOUTH_BEACH_BOROUGH = "47130"
MONMOUTH_JUNCTION_CDP = "47190"
MONROE_MANOR_CDP = "47380"
MONTCLAIR_STATE_UNIVERSITY_CDP = "47524"
MONTVALE_BOROUGH = "47610"
MOONACHIE_BOROUGH = "47700"
MOORESTOWN_LENOLA_CDP = "47895"
MORGANVILLE_CDP = "48030"
MORRIS_PLAINS_BOROUGH = "48210"
MORRISTOWN_TOWN = "48300"
MOUNT_ARLINGTON_BOROUGH = "48690"
MOUNT_EPHRAIM_BOROUGH = "48750"
MOUNT_HERMON_CDP = "48840"
MOUNT_HOPE_CDP = "48930"
MOUNT_ROYAL_CDP = "49200"
MOUNT_TABOR_CDP = "49290"
MOUNTAIN_LAKE_CDP = "48450"
MOUNTAIN_LAKES_BOROUGH = "48480"
MOUNTAINSIDE_BOROUGH = "48510"
MULLICA_HILL_CDP = "49440"
MYSTIC_ISLAND_CDP = "49560"
NATIONAL_PARK_BOROUGH = "49680"
NAVESINK_CDP = "49740"
NEPTUNE_CITY_BOROUGH = "49920"
NESCO_CDP = "50010"
NESHANIC_CDP = "50040"
NESHANIC_STATION_CDP = "50100"
NETCONG_BOROUGH = "50130"
NEW_BRUNSWICK_CITY = "51210"
NEW_EGYPT_CDP = "51360"
NEW_GRETNA_CDP = "51450"
NEW_MILFORD_BOROUGH = "51660"
NEW_PROVIDENCE_BOROUGH = "51810"
NEW_VERNON_CDP = "52020"
NEW_VILLAGE_CDP = "52050"
NEWARK_CITY = "51000"
NEWFIELD_BOROUGH = "51390"
NEWFOUNDLAND_CDP = "51420"
NEWPORT_CDP = "51750"
NEWTON_TOWN = "51930"
NEWTONVILLE_CDP = "51990"
NORTH_ARLINGTON_BOROUGH = "52320"
NORTH_BEACH_HAVEN_CDP = "52410"
NORTH_CALDWELL_BOROUGH = "52620"
NORTH_CAPE_MAY_CDP = "52650"
NORTH_HALEDON_BOROUGH = "53040"
NORTH_MIDDLETOWN_CDP = "53205"
NORTH_PLAINFIELD_BOROUGH = "53280"
NORTH_WILDWOOD_CITY = "53490"
NORTHFIELD_CITY = "52950"
NORTHVALE_BOROUGH = "53430"
NORWOOD_BOROUGH = "53610"
OAK_RIDGE_CDP = "53910"
OAK_VALLEY_CDP = "54060"
OAKHURST_CDP = "53790"
OAKLAND_BOROUGH = "53850"
OAKLYN_BOROUGH = "53880"
OCEAN_ACRES_CDP = "54315"
OCEAN_CITY_CITY = "54360"
OCEAN_GATE_BOROUGH = "54450"
OCEAN_GROVE_CDP = "54480"
OCEAN_VIEW_CDP = "54600"
OCEANPORT_BOROUGH = "54570"
OCEANVILLE_CDP = "54630"
OGDENSBURG_BOROUGH = "54660"
OLD_BRIDGE_CDP = "54690"
OLD_TAPPAN_BOROUGH = "54870"
OLDWICK_CDP = "54900"
OLIVET_CDP = "54960"
ORADELL_BOROUGH = "54990"
OTHELLO_CDP = "55320"
OXFORD_CDP = "55500"
PACKANACK_LAKE_CDP = "55620"
PALERMO_CDP = "55710"
PALISADES_PARK_BOROUGH = "55770"
PALMYRA_BOROUGH = "55800"
PANTHER_VALLEY_CDP = "55895"
PARAMUS_BOROUGH = "55950"
PARK_RIDGE_BOROUGH = "56130"
PARSIPPANY_CDP = "56430"
PASSAIC_CITY = "56550"
PATERSON_CITY = "57000"
PAULSBORO_BOROUGH = "57150"
PEAPACK_AND_GLADSTONE_BOROUGH = "57300"
PEDRICKTOWN_CDP = "57360"
PEMBERTON_HEIGHTS_CDP = "57540"
PEMBERTON_BOROUGH = "57480"
PENNINGTON_BOROUGH = "57600"
PENNS_GROVE_BOROUGH = "57750"
PENNSVILLE_CDP = "57840"
PERTH_AMBOY_CITY = "58200"
PHILLIPSBURG_TOWN = "58350"
PINE_BEACH_BOROUGH = "58590"
PINE_BROOK_CDP = "58650"
PINE_HILL_BOROUGH = "58770"
PINE_LAKE_PARK_CDP = "58830"
PINE_RIDGE_AT_CRESTWOOD_CDP = "58852"
PINES_LAKE_CDP = "58860"
PITMAN_BOROUGH = "59070"
PLAINFIELD_CITY = "59190"
PLAINSBORO_CENTER_CDP = "59285"
PLEASANT_PLAINS_CDP = "59500"
PLEASANTDALE_CDP = "59385"
PLEASANTVILLE_CITY = "59640"
PLUCKEMIN_CDP = "59730"
POINT_PLEASANT_BEACH_BOROUGH = "59910"
POINT_PLEASANT_BOROUGH = "59880"
POMONA_CDP = "60030"
POMPTON_LAKES_BOROUGH = "60090"
POMPTON_PLAINS_CDP = "60120"
PORT_COLDEN_CDP = "60210"
PORT_ELIZABETH_CDP = "60240"
PORT_MONMOUTH_CDP = "60360"
PORT_MORRIS_CDP = "60390"
PORT_MURRAY_CDP = "60450"
PORT_NORRIS_CDP = "60510"
PORT_READING_CDP = "60540"
PORT_REPUBLIC_CITY = "60600"
POTTERSVILLE_CDP = "60750"
PREAKNESS_CDP = "60810"
PRESIDENTIAL_LAKES_ESTATES_CDP = "60840"
PRINCETON_JUNCTION_CDP = "60960"
PRINCETON_MEADOWS_CDP = "60975"
PRINCETON = "60900"
PROSPECT_PARK_BOROUGH = "61170"
QUINTON_CDP = "61440"
RAHWAY_CITY = "61530"
RAINBOW_LAKES_CDP = "61560"
RAMAPO_COLLEGE_OF_NEW_JERSEY_CDP = "61632"
RAMBLEWOOD_CDP = "61650"
RAMSEY_BOROUGH = "61680"
RAMTOWN_CDP = "61725"
RARITAN_BOROUGH = "61980"
RED_BANK_BOROUGH = "62430"
REGENCY_AT_MONROE_CDP = "62585"
RENAISSANCE_AT_MONROE_CDP = "62605"
RICHLAND_CDP = "62790"
RICHWOOD_CDP = "62820"
RIDGEFIELD_PARK_VILLAGE = "62940"
RIDGEFIELD_BOROUGH = "62910"
RIDGEWOOD_VILLAGE = "63000"
RINGOES_CDP = "63120"
RINGWOOD_BOROUGH = "63150"
RIO_GRANDE_CDP = "63180"
RIVER_EDGE_BOROUGH = "63360"
RIVERDALE_BOROUGH = "63300"
RIVERTON_BOROUGH = "63660"
ROADSTOWN_CDP = "63810"
ROBBINSVILLE_CENTER_CDP = "63858"
ROBERTSVILLE_CDP = "63900"
ROCKAWAY_BOROUGH = "64050"
ROCKLEIGH_BOROUGH = "64170"
ROCKY_HILL_BOROUGH = "64320"
ROEBLING_CDP = "64350"
ROOSEVELT_BOROUGH = "64410"
ROSELAND_BOROUGH = "64590"
ROSELLE_PARK_BOROUGH = "64650"
ROSELLE_BOROUGH = "64620"
ROSENHAYN_CDP = "64740"
ROSS_CORNER_CDP = "64860"
ROSSMOOR_CDP = "64865"
RUMSON_BOROUGH = "65130"
RUNNEMEDE_BOROUGH = "65160"
RUTGERS_UNIVERSITY_BUSCH_CAMPUS_CDP = "65249"
RUTGERS_UNIVERSITY_LIVINGSTON_CAMPUS_CDP = "65260"
RUTHERFORD_BOROUGH = "65280"
SADDLE_RIVER_BOROUGH = "65400"
SALEM_CITY = "65490"
SAYREVILLE_BOROUGH = "65790"
SEA_BRIGHT_BOROUGH = "66240"
SEA_GIRT_BOROUGH = "66330"
SEA_ISLE_CITY_CITY = "66390"
SEABROOK_FARMS_CDP = "66300"
SEASIDE_HEIGHTS_BOROUGH = "66450"
SEASIDE_PARK_BOROUGH = "66480"
SEAVILLE_CDP = "66540"
SECAUCUS_TOWN = "66570"
SEELEY_CDP = "66615"
SEWAREN_CDP = "66720"
SEWELL_CDP = "66750"
SHARK_RIVER_HILLS_CDP = "66840"
SHEPPARDS_MILL_CDP = "66970"
SHILOH_BOROUGH = "67020"
SHIP_BOTTOM_BOROUGH = "67110"
SHORT_HILLS_CDP = "67320"
SHREWSBURY_BOROUGH = "67350"
SICKLERVILLE_CDP = "67470"
SILVER_LAKE_CDP_CUMBERLAND_COUNTY = "67583"
SILVER_LAKE_CDP_ESSEX_COUNTY = "67590"
SILVER_LAKE_CDP_WARREN_COUNTY = "67650"
SILVER_RIDGE_CDP = "67665"
SINGAC_CDP = "67770"
SIX_MILE_RUN_CDP = "67820"
SKILLMAN_CDP = "67860"
SMITHVILLE_CDP = "68190"
SOMERDALE_BOROUGH = "68340"
SOMERS_POINT_CITY = "68430"
SOMERSET_CDP = "68370"
SOMERVILLE_BOROUGH = "68460"
SOUTH_AMBOY_CITY = "68550"
SOUTH_BOUND_BROOK_BOROUGH = "68730"
SOUTH_DENNIS_CDP = "68850"
SOUTH_PLAINFIELD_BOROUGH = "69390"
SOUTH_RIVER_BOROUGH = "69420"
SOUTH_SEAVILLE_CDP = "69480"
SOUTH_TOMS_RIVER_BOROUGH = "69510"
SPOTSWOOD_BOROUGH = "69810"
SPRING_LAKE_HEIGHTS_BOROUGH = "70140"
SPRING_LAKE_BOROUGH = "70110"
SPRINGDALE_CDP = "69900"
SPRINGFIELD_CDP = "70018"
STANHOPE_BOROUGH = "70380"
STEWARTSVILLE_CDP = "70800"
STIRLING_CDP = "70920"
STOCKTON_UNIVERSITY_CDP = "70984"
STOCKTON_BOROUGH = "70980"
STONE_HARBOR_BOROUGH = "71010"
STONEBRIDGE_CDP = "70987"
STRATFORD_BOROUGH = "71220"
STRATHMERE_CDP = "71250"
STRATHMORE_CDP = "71280"
SUCCASUNNA_CDP = "71370"
SUMMIT_CITY = "71430"
SUNSET_LAKE_CDP = "71628"
SURF_CITY_BOROUGH = "71640"
SUSSEX_BOROUGH = "71670"
SWEDESBORO_BOROUGH = "71850"
SWEETWATER_CDP = "71880"
TAVISTOCK_BOROUGH = "72240"
TEN_MILE_RUN_CDP = "72435"
TENAFLY_BOROUGH = "72420"
TETERBORO_BOROUGH = "72480"
THE_COLLEGE_OF_NEW_JERSEY_CDP = "72580"
THE_HILLS_CDP = "72635"
THE_PONDS_CDP = "72726"
THOROFARE_CDP = "72810"
THREE_BRIDGES_CDP = "72870"
TINTON_FALLS_BOROUGH = "73020"
TITUSVILLE_CDP = "73050"
TOMS_RIVER_CDP = "73110"
TOTOWA_BOROUGH = "73140"
TOWACO_CDP = "73170"
TRENTON_CITY = "74000"
TROY_HILLS_CDP = "74150"
TUCKAHOE_CDP = "74180"
TUCKERTON_BOROUGH = "74210"
TURNERSVILLE_CDP = "74270"
TWIN_RIVERS_CDP = "74330"
UNION_BEACH_BOROUGH = "74540"
UNION_CDP = "74478"
UNION_CITY_CITY = "74630"
UPPER_GREENWOOD_LAKE_CDP = "74930"
UPPER_MONTCLAIR_CDP = "75020"
UPPER_POHATCONG_CDP = "75120"
UPPER_SADDLE_RIVER_BOROUGH = "75140"
UPPER_STEWARTSVILLE_CDP = "75145"
VAUXHALL_CDP = "75590"
VENTNOR_CITY_CITY = "75620"
VERNON_CENTER_CDP = "75745"
VERNON_VALLEY_CDP = "75750"
VICTORY_GARDENS_BOROUGH = "75890"
VICTORY_LAKES_CDP = "75920"
VIENNA_CDP = "75950"
VILLAS_CDP = "76010"
VINCENTOWN_CDP = "76040"
VINELAND_CITY = "76070"
VISTA_CENTER_CDP = "76107"
VOORHEES_CDP = "76250"
WALDWICK_BOROUGH = "76400"
WALLINGTON_BOROUGH = "76490"
WANAMASSA_CDP = "76700"
WANAQUE_BOROUGH = "76730"
WARETOWN_CDP = "76820"
WASHINGTON_CROSSING_CDP = "77330"
WASHINGTON_BOROUGH = "77270"
WATCHUNG_BOROUGH = "77600"
WATSESSING_CDP = "77750"
WENONAH_BOROUGH = "78110"
WEST_BELMAR_CDP = "78350"
WEST_BERLIN_CDP = "78410"
WEST_CAPE_MAY_BOROUGH = "78530"
WEST_FREEHOLD_CDP = "79100"
WEST_LONG_BRANCH_BOROUGH = "79310"
WEST_NEW_YORK_TOWN = "79610"
WEST_PARK_CDP = "79810"
WEST_WILDWOOD_BOROUGH = "80210"
WESTFIELD_TOWN = "79040"
WESTMONT_CDP = "79520"
WESTON_CDP = "79715"
WESTVILLE_BOROUGH = "80120"
WESTWOOD_BOROUGH = "80270"
WHARTON_BOROUGH = "80390"
WHIPPANY_CDP = "80540"
WHITE_HORSE_CDP = "80630"
WHITE_HOUSE_STATION_CDP = "80720"
WHITE_MEADOW_LAKE_CDP = "80750"
WHITESBORO_CDP = "80840"
WHITTINGHAM_CDP = "81042"
WILDWOOD_CREST_BOROUGH = "81200"
WILDWOOD_CITY = "81170"
WILLIAM_PATERSON_UNIVERSITY_OF_NEW_JERSEY_CDP = "81365"
WILLIAMSTOWN_CDP = "81380"
WINDSOR_CDP = "81620"
WOOD_RIDGE_BOROUGH = "82570"
WOODBINE_BOROUGH = "81890"
WOODBRIDGE_CDP = "81950"
WOODBURY_HEIGHTS_BOROUGH = "82180"
WOODBURY_CITY = "82120"
WOODCLIFF_LAKE_BOROUGH = "82300"
WOODLAND_PARK_BOROUGH = "82423"
WOODLYNNE_BOROUGH = "82450"
WOODSTOWN_BOROUGH = "82720"
WRIGHTSTOWN_BOROUGH = "82960"
YARDVILLE_CDP = "83170"
YORKETOWN_CDP = "83245"
ZAREPHATH_CDP = "83290"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Alabama."""


AUTAUGA = "001"
BALDWIN = "003"
BARBOUR = "005"
BIBB = "007"
BLOUNT = "009"
BULLOCK = "011"
BUTLER = "013"
CALHOUN = "015"
CHAMBERS = "017"
CHEROKEE = "019"
CHILTON = "021"
CHOCTAW = "023"
CLARKE = "025"
CLAY = "027"
CLEBURNE = "029"
COFFEE = "031"
COLBERT = "033"
CONECUH = "035"
COOSA = "037"
COVINGTON = "039"
CRENSHAW = "041"
CULLMAN = "043"
DALE = "045"
DALLAS = "047"
DEKALB = "049"
ELMORE = "051"
ESCAMBIA = "053"
ETOWAH = "055"
FAYETTE = "057"
FRANKLIN = "059"
GENEVA = "061"
GREENE = "063"
HALE = "065"
HENRY = "067"
HOUSTON = "069"
JACKSON = "071"
JEFFERSON = "073"
LAMAR = "075"
LAUDERDALE = "077"
LAWRENCE = "079"
LEE = "081"
LIMESTONE = "083"
LOWNDES = "085"
MACON = "087"
MADISON = "089"
MARENGO = "091"
MARION = "093"
MARSHALL = "095"
MOBILE = "097"
MONROE = "099"
MONTGOMERY = "101"
MORGAN = "103"
PERRY = "105"
PICKENS = "107"
PIKE = "109"
RANDOLPH = "111"
RUSSELL = "113"
SHELBY = "117"
ST_CLAIR = "115"
SUMTER = "119"
TALLADEGA = "121"
TALLAPOOSA = "123"
TUSCALOOSA = "125"
WALKER = "127"
WASHINGTON = "129"
WILCOX = "131"
WINSTON = "133"



# Copyright (c) 2022 Darren Erik Vengroff
"""
Special estimate values that may be returned from the U.S. Census API.

See https://www.census.gov/data/developers/data-sets/acs-1year/notes-on-acs-estimate-and-annotation-values.html
"""

INSUFFICIENT_SAMPLE_OBSERVATIONS = -666666666
"""
Insufficient number of sample observations.

The estimate could not be computed because there were an insufficient number of sample observations.
For a ratio of medians estimate, one or both of the median estimates falls in the lowest interval or
highest interval of an open-ended distribution. The estimate could not be computed because there were
an insufficient number of sample observations. For a ratio of medians estimate, one or both of the
median estimates falls in the lowest interval or highest interval of an open-ended distribution. For
a 5-year median estimate, the margin of error associated with a median was larger than the median itself.
"""

INSUFFICIENT_SAMPLES_IN_GEOGRAPHY = -999999999
"""
Insufficient samples in geography.

The estimate or margin of error cannot be displayed because there were an insufficient number of sample
cases in the selected geographic area.
"""

NOT_APPLICABLE_OR_NOT_AVAILABLE = -888888888
"""
Not applicable or not available.

The estimate or margin of error is not applicable or not available.
"""

INSUFFICIENT_SAMPLE_OBSERVATIONS_FOR_MARGIN_OF_ERROR = -222222222
"""
Insufficient sample observations for margin of error.

The margin of error could not be computed because there were an insufficient number of sample observations.
"""

MEDIAN_IN_OPEN_INTERVAL = -333333333
"""
Median falls in an open-ended interval.

The margin of error could not be computed because the median falls in the lowest interval or highest interval
of an open-ended distribution.
"""

MARGIN_OF_ERROR_NOT_APPROPRIATE = -555555555
"""
Margin of error not appropriate.

A margin of error is not appropriate because the corresponding estimate is controlled to an independent
population or housing estimate. Effectively, the corresponding estimate has no sampling error and the margin
of error may be treated as zero.
"""

ALL_SPECIAL_VALUES = (
    INSUFFICIENT_SAMPLE_OBSERVATIONS,
    INSUFFICIENT_SAMPLES_IN_GEOGRAPHY,
    NOT_APPLICABLE_OR_NOT_AVAILABLE,
    INSUFFICIENT_SAMPLE_OBSERVATIONS_FOR_MARGIN_OF_ERROR,
    MEDIAN_IN_OPEN_INTERVAL,
    MARGIN_OF_ERROR_NOT_APPROPRIATE,
)



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in South Dakota."""


AURORA = "003"
BEADLE = "005"
BENNETT = "007"
BON_HOMME = "009"
BROOKINGS = "011"
BROWN = "013"
BRULE = "015"
BUFFALO = "017"
BUTTE = "019"
CAMPBELL = "021"
CHARLES_MIX = "023"
CLARK = "025"
CLAY = "027"
CODINGTON = "029"
CORSON = "031"
CUSTER = "033"
DAVISON = "035"
DAY = "037"
DEUEL = "039"
DEWEY = "041"
DOUGLAS = "043"
EDMUNDS = "045"
FALL_RIVER = "047"
FAULK = "049"
GRANT = "051"
GREGORY = "053"
HAAKON = "055"
HAMLIN = "057"
HAND = "059"
HANSON = "061"
HARDING = "063"
HUGHES = "065"
HUTCHINSON = "067"
HYDE = "069"
JACKSON = "071"
JERAULD = "073"
JONES = "075"
KINGSBURY = "077"
LAKE = "079"
LAWRENCE = "081"
LINCOLN = "083"
LYMAN = "085"
MARSHALL = "091"
MCCOOK = "087"
MCPHERSON = "089"
MEADE = "093"
MELLETTE = "095"
MINER = "097"
MINNEHAHA = "099"
MOODY = "101"
OGLALA_LAKOTA = "102"
PENNINGTON = "103"
PERKINS = "105"
POTTER = "107"
ROBERTS = "109"
SANBORN = "111"
SPINK = "115"
STANLEY = "117"
SULLY = "119"
TODD = "121"
TRIPP = "123"
TURNER = "125"
UNION = "127"
WALWORTH = "129"
YANKTON = "135"
ZIEBACH = "137"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Idaho."""


ABERDEEN_CITY = "00100"
ACEQUIA_CITY = "00280"
ALBION_CITY = "01000"
AMERICAN_FALLS_CITY = "01900"
AMMON_CITY = "01990"
ARBON_VALLEY_CDP = "02935"
ARCO_CITY = "03160"
ARIMO_CITY = "03340"
ASHTON_CITY = "03610"
ATHOL_CITY = "03700"
ATOMIC_CITY_CITY = "03970"
AVIMOR_CDP = "04105"
BANCROFT_CITY = "04420"
BANKS_CDP = "04600"
BASALT_CITY = "05230"
BELLEVUE_CITY = "06220"
BENNINGTON_CDP = "06670"
BLACKFOOT_CITY = "07840"
BLANCHARD_CDP = "08290"
BLISS_CITY = "08470"
BLOOMINGTON_CITY = "08560"
BOISE_CITY_CITY = "08830"
BONNERS_FERRY_CITY = "09370"
BOVILL_CITY = "09730"
BRUNEAU_CDP = "10450"
BUHL_CITY = "10810"
BURLEY_CITY = "11260"
BUTTE_CITY_CITY = "11710"
CALDWELL_CITY = "12250"
CAMBRIDGE_CITY = "12520"
CAREY_CITY = "12790"
CASCADE_CITY = "13150"
CASTLEFORD_CITY = "13240"
CHALLIS_CITY = "13780"
CHUBBUCK_CITY = "14680"
CLARK_FORK_CITY = "14950"
CLAYTON_CITY = "15490"
CLIFTON_CITY = "16120"
COEUR_DALENE_CITY = "16750"
CONKLING_PARK_CDP = "17830"
COOLIN_CDP = "18010"
COTTONWOOD_CITY = "18640"
COUNCIL_CITY = "18820"
CRAIGMONT_CITY = "19270"
CROUCH_CITY = "19720"
CULDESAC_CITY = "19900"
DALTON_GARDENS_CITY = "20350"
DAYTON_CITY = "20710"
DE_SMET_CDP = "21520"
DEARY_CITY = "20890"
DECLO_CITY = "20980"
DIETRICH_CITY = "21790"
DONNELLY_CITY = "22330"
DOVER_CITY = "22510"
DOWNEY_CITY = "22600"
DRIGGS_CITY = "22690"
DRUMMOND_CITY = "22780"
DUBOIS_CITY = "22960"
EAGLE_CITY = "23410"
EAST_HOPE_CITY = "23680"
EDEN_CITY = "24310"
ELK_CITY_CDP = "25030"
ELK_RIVER_CITY = "25120"
EMMETT_CITY = "25570"
FAIRFIELD_CITY = "26290"
FERDINAND_CITY = "27460"
FERNAN_LAKE_VILLAGE_CITY = "27550"
FERNWOOD_CDP = "27640"
FILER_CITY = "27730"
FIRTH_CITY = "27910"
FORT_HALL_CDP = "28360"
FRANKLIN_CITY = "28810"
FRUITLAND_CITY = "28990"
GANNETT_CDP = "29440"
GARDEN_CITY_CITY = "29620"
GARDEN_VALLEY_CDP = "29710"
GENESEE_CITY = "30160"
GEORGETOWN_CITY = "30340"
GLENNS_FERRY_CITY = "31690"
GOODING_CITY = "32140"
GRACE_CITY = "32500"
GRAND_VIEW_CITY = "32770"
GRANGEVILLE_CITY = "32950"
GREENLEAF_CITY = "33490"
GROVELAND_CDP = "34030"
HAGERMAN_CITY = "34300"
HAILEY_CITY = "34390"
HAMER_CITY = "34570"
HAMMETT_CDP = "34750"
HANSEN_CITY = "34930"
HARRISON_CITY = "35200"
HAUSER_CITY = "35830"
HAYDEN_LAKE_CITY = "36460"
HAYDEN_CITY = "36370"
HAZELTON_CITY = "36730"
HEYBURN_CITY = "37360"
HIDDEN_SPRINGS_CDP = "37500"
HOLLISTER_CITY = "38080"
HOMEDALE_CITY = "38170"
HOPE_CITY = "38440"
HORSESHOE_BEND_CITY = "38620"
HUETTER_CITY = "39070"
IDAHO_CITY_CITY = "39610"
IDAHO_FALLS_CITY = "39700"
INKOM_CITY = "40330"
IONA_CITY = "40420"
IRWIN_CITY = "40510"
ISLAND_PARK_CITY = "40600"
JEROME_CITY = "41320"
JULIAETTA_CITY = "42130"
KAMIAH_CITY = "42400"
KELLOGG_CITY = "42580"
KENDRICK_CITY = "42760"
KETCHUM_CITY = "43030"
KIMBERLY_CITY = "43570"
KOOSKIA_CITY = "44110"
KOOTENAI_CITY = "44200"
KUNA_CITY = "44290"
LACLEDE_CDP = "44560"
LAPWAI_CITY = "45370"
LAVA_HOT_SPRINGS_CITY = "45820"
LEADORE_CITY = "45910"
LETHA_CDP = "46450"
LEWISTON_CITY = "46540"
LEWISVILLE_CITY = "46720"
LINCOLN_CDP = "47080"
LOST_RIVER_CITY = "47890"
LOWMAN_CDP = "48250"
MACKAY_CITY = "49240"
MALAD_CITY_CITY = "50140"
MALTA_CITY = "50230"
MARSING_CITY = "50950"
MCCALL_CITY = "48790"
MCCAMMON_CITY = "48880"
MELBA_CITY = "51850"
MENAN_CITY = "52030"
MERIDIAN_CITY = "52120"
MIDDLETON_CITY = "52660"
MIDVALE_CITY = "52750"
MINIDOKA_CITY = "53110"
MONTPELIER_CITY = "53920"
MOORE_CITY = "54100"
MORELAND_CDP = "54370"
MOSCOW_CITY = "54550"
MOUNTAIN_HOME_AFB_CDP = "54820"
MOUNTAIN_HOME_CITY = "54730"
MOYIE_SPRINGS_CITY = "55270"
MUD_LAKE_CITY = "55450"
MULLAN_CITY = "55630"
MURPHY_CDP = "55720"
MURTAUGH_CITY = "55900"
NAMPA_CITY = "56260"
NEW_MEADOWS_CITY = "56890"
NEW_PLYMOUTH_CITY = "56980"
NEWDALE_CITY = "56800"
NEZPERCE_CITY = "57250"
NOTUS_CITY = "58060"
OAKLEY_CITY = "58330"
OLDTOWN_CITY = "58600"
ONAWAY_CITY = "58870"
OROFINO_CITY = "59320"
OSBURN_CITY = "59590"
OXFORD_CITY = "60040"
PARIS_CITY = "60580"
PARKER_CITY = "60760"
PARKLINE_CDP = "60880"
PARMA_CITY = "60940"
PAUL_CITY = "61210"
PAYETTE_CITY = "61300"
PECK_CITY = "61840"
PIERCE_CITY = "62740"
PINEHURST_CITY = "63100"
PLACERVILLE_CITY = "63550"
PLUMMER_CITY = "63910"
POCATELLO_CITY = "64090"
PONDERAY_CITY = "64450"
POST_FALLS_CITY = "64810"
POTLATCH_CITY = "64900"
PRESTON_CITY = "65260"
PRIEST_RIVER_CITY = "65530"
PRINCETON_CDP = "65620"
RATHDRUM_CITY = "66340"
REUBENS_CITY = "67150"
REXBURG_CITY = "67420"
RICHFIELD_CITY = "67600"
RIGBY_CITY = "67780"
RIGGINS_CITY = "67870"
RIRIE_CITY = "67960"
RIVERSIDE_CDP = "68230"
ROBERTS_CITY = "68500"
ROBIE_CREEK_CDP = "68545"
ROCKFORD_BAY_CDP = "68950"
ROCKFORD_CDP = "68860"
ROCKLAND_CITY = "69130"
RUPERT_CITY = "70660"
SALMON_CITY = "71650"
SANDPOINT_CITY = "72100"
SHELLEY_CITY = "73450"
SHOSHONE_CITY = "73900"
SILVERTON_CDP = "74440"
SMELTERVILLE_CITY = "75070"
SMITHS_FERRY_CDP = "75160"
SODA_SPRINGS_CITY = "75195"
SPENCER_CITY = "75970"
SPIRIT_LAKE_CITY = "76060"
ST_ANTHONY_CITY = "71020"
ST_CHARLES_CITY = "71110"
ST_MARIES_CITY = "71470"
STANLEY_CITY = "76780"
STAR_CITY = "76870"
STATE_LINE_CITY = "77050"
STITES_CITY = "77500"
SUGAR_CITY_CITY = "78040"
SUN_VALLEY_CITY = "78850"
SWAN_VALLEY_CITY = "79120"
SWEETWATER_CDP = "79300"
TENSED_CITY = "80200"
TETON_CITY = "80380"
TETONIA_CITY = "80470"
TROY_CITY = "82360"
TWIN_FALLS_CITY = "82810"
TYHEE_CDP = "83170"
UCON_CITY = "83350"
VICTOR_CITY = "84250"
VIOLA_CDP = "84430"
WALLACE_CITY = "84790"
WARDNER_CITY = "85240"
WARM_RIVER_CITY = "85420"
WEIPPE_CITY = "86050"
WEISER_CITY = "86140"
WENDELL_CITY = "86320"
WESTON_CITY = "87040"
WHITE_BIRD_CITY = "87310"
WILDER_CITY = "87670"
WINCHESTER_CITY = "87850"
WORLEY_CITY = "88480"
YELLOW_PINE_CDP = "88660"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Wyoming."""


ALBANY = "001"
BIG_HORN = "003"
CAMPBELL = "005"
CARBON = "007"
CONVERSE = "009"
CROOK = "011"
FREMONT = "013"
GOSHEN = "015"
HOT_SPRINGS = "017"
JOHNSON = "019"
LARAMIE = "021"
LINCOLN = "023"
NATRONA = "025"
NIOBRARA = "027"
PARK = "029"
PLATTE = "031"
SHERIDAN = "033"
SUBLETTE = "035"
SWEETWATER = "037"
TETON = "039"
UINTA = "041"
WASHAKIE = "043"
WESTON = "045"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in California."""


ALAMEDA = "001"
ALPINE = "003"
AMADOR = "005"
BUTTE = "007"
CALAVERAS = "009"
COLUSA = "011"
CONTRA_COSTA = "013"
DEL_NORTE = "015"
EL_DORADO = "017"
FRESNO = "019"
GLENN = "021"
HUMBOLDT = "023"
IMPERIAL = "025"
INYO = "027"
KERN = "029"
KINGS = "031"
LAKE = "033"
LASSEN = "035"
LOS_ANGELES = "037"
MADERA = "039"
MARIN = "041"
MARIPOSA = "043"
MENDOCINO = "045"
MERCED = "047"
MODOC = "049"
MONO = "051"
MONTEREY = "053"
NAPA = "055"
NEVADA = "057"
ORANGE = "059"
PLACER = "061"
PLUMAS = "063"
RIVERSIDE = "065"
SACRAMENTO = "067"
SAN_BENITO = "069"
SAN_BERNARDINO = "071"
SAN_DIEGO = "073"
SAN_FRANCISCO = "075"
SAN_JOAQUIN = "077"
SAN_LUIS_OBISPO = "079"
SAN_MATEO = "081"
SANTA_BARBARA = "083"
SANTA_CLARA = "085"
SANTA_CRUZ = "087"
SHASTA = "089"
SIERRA = "091"
SISKIYOU = "093"
SOLANO = "095"
SONOMA = "097"
STANISLAUS = "099"
SUTTER = "101"
TEHAMA = "103"
TRINITY = "105"
TULARE = "107"
TUOLUMNE = "109"
VENTURA = "111"
YOLO = "113"
YUBA = "115"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Oregon."""


ADAIR_VILLAGE_CITY = "00275"
ADAMS_CITY = "00350"
ADRIAN_CITY = "00500"
ALBANY_CITY = "01000"
ALOHA_CDP = "01650"
ALPINE_CDP = "01700"
ALSEA_CDP = "01800"
ALTAMONT_CDP = "01850"
AMITY_CITY = "02000"
ANNEX_CDP = "02200"
ANTELOPE_CITY = "02250"
ARLINGTON_CITY = "02800"
ASHLAND_CITY = "03050"
ASTORIA_CITY = "03150"
ATHENA_CITY = "03200"
AUMSVILLE_CITY = "03250"
AURORA_CITY = "03300"
BAKER_CITY_CITY = "03650"
BANDON_CITY = "03800"
BANKS_CITY = "03850"
BARLOW_CITY = "04000"
BARNESDALE_CDP = "04125"
BARVIEW_CDP = "04400"
BAY_CITY_CITY = "04800"
BAYSHORE_CDP = "04850"
BAYSIDE_GARDENS_CDP = "04925"
BEATTY_CDP = "05150"
BEAVER_CDP = "05200"
BEAVER_MARSH_CDP = "05300"
BEAVERCREEK_CDP = "05250"
BEAVERTON_CITY = "05350"
BELLFOUNTAIN_CDP = "05700"
BEND_CITY = "05800"
BETHANY_CDP = "05950"
BIGGS_JUNCTION_CDP = "06400"
BLACK_BUTTE_RANCH_CDP = "06650"
BLODGETT_CDP = "06950"
BLY_CDP = "07150"
BOARDMAN_CITY = "07200"
BONANZA_TOWN = "07300"
BORING_CDP = "07550"
BROGAN_CDP = "08600"
BROOKINGS_CITY = "08650"
BROOKS_CDP = "08750"
BROWNSVILLE_CITY = "09050"
BULL_MOUNTAIN_CDP = "09535"
BUNKER_HILL_CDP = "09600"
BURNS_CITY = "09800"
BUTTE_FALLS_TOWN = "10050"
BUTTEVILLE_CDP = "10100"
CAMP_SHERMAN_CDP = "10550"
CANBY_CITY = "10750"
CANNON_BEACH_CITY = "10850"
CANYON_CITY_TOWN = "10950"
CANYONVILLE_CITY = "11000"
CAPE_MEARES_CDP = "11050"
CARLTON_CITY = "11150"
CASCADE_LOCKS_CITY = "11600"
CASCADIA_CDP = "11700"
CAVE_JUNCTION_CITY = "11850"
CAYUSE_CDP = "11900"
CEDAR_HILLS_CDP = "12050"
CEDAR_MILL_CDP = "12150"
CENTRAL_POINT_CITY = "12400"
CHEMULT_CDP = "12750"
CHENOWETH_CDP = "12800"
CHERRY_GROVE_CDP = "12850"
CHESHIRE_CDP = "13000"
CHILOQUIN_CITY = "13050"
CLATSKANIE_CITY = "13750"
CLOVERDALE_CDP = "14200"
COBURG_CITY = "14400"
COLUMBIA_CITY_CITY = "14750"
CONDON_CITY = "15000"
COOS_BAY_CITY = "15250"
COQUILLE_CITY = "15350"
CORNELIUS_CITY = "15550"
CORVALLIS_CITY = "15800"
COTTAGE_GROVE_CITY = "15950"
COVE_CITY = "16250"
CRABTREE_CDP = "16350"
CRANE_CDP = "16450"
CRAWFORDSVILLE_CDP = "16650"
CRESCENT_CDP = "16750"
CRESCENT_LAKE_CDP = "16800"
CRESWELL_CITY = "16950"
CROOKED_RIVER_RANCH_CDP = "16975"
CULVER_CITY = "17300"
DALLAS_CITY = "17700"
DAMASCUS_CDP = "17800"
DAYS_CREEK_CDP = "18150"
DAYTON_CITY = "18250"
DAYVILLE_TOWN = "18300"
DEER_ISLAND_CDP = "18450"
DEPOE_BAY_CITY = "18850"
DESCHUTES_RIVER_WOODS_CDP = "19020"
DETROIT_CITY = "19100"
DEXTER_CDP = "19250"
DILLARD_CDP = "19600"
DILLEY_CDP = "19650"
DONALD_CITY = "20100"
DRAIN_CITY = "20500"
DUFUR_CITY = "20900"
DUNDEE_CITY = "21050"
DUNES_CITY_CITY = "21150"
DUNTHORPE_CDP = "21215"
DURHAM_CITY = "21250"
EAGLE_CREST_CDP = "21450"
EAGLE_POINT_CITY = "21550"
ECHO_CITY = "22200"
ELGIN_CITY = "22550"
ELKTON_CITY = "22800"
ELMIRA_CDP = "23000"
ENTERPRISE_CITY = "23500"
EOLA_CDP = "23550"
ESTACADA_CITY = "23800"
EUGENE_CITY = "23850"
FAIR_OAKS_CDP = "24100"
FAIRVIEW_CDP = "24300"
FAIRVIEW_CITY = "24250"
FALCON_HEIGHTS_CDP = "24350"
FALLS_CITY_CITY = "24550"
FLORENCE_CITY = "26050"
FOOTS_CREEK_CDP = "26165"
FOREST_GROVE_CITY = "26200"
FORT_HILL_CDP = "26400"
FORT_KLAMATH_CDP = "26450"
FOSSIL_CITY = "26650"
FOUR_CORNERS_CDP = "26750"
GARDEN_HOME_WHITFORD_CDP = "27825"
GARDINER_CDP = "27850"
GARIBALDI_CITY = "28000"
GASTON_CITY = "28100"
GATES_CITY = "28200"
GEARHART_CITY = "28450"
GERVAIS_CITY = "28650"
GILCHRIST_CDP = "28800"
GLADSTONE_CITY = "29000"
GLASGOW_CDP = "29100"
GLENDALE_CITY = "29350"
GLIDE_CDP = "29750"
GOLD_BEACH_CITY = "29900"
GOLD_HILL_CITY = "29950"
GOPHER_FLATS_CDP = "30165"
GOVERNMENT_CAMP_CDP = "30250"
GRAND_RONDE_CDP = "30300"
GRANITE_CITY = "30500"
GRANTS_PASS_CITY = "30550"
GRASS_VALLEY_CITY = "30650"
GREEN_CDP = "30750"
GREEN_MEADOWS_CDP = "31115"
GREENHORN_CITY = "31050"
GRESHAM_CITY = "31250"
HAINES_CITY = "31600"
HALFWAY_CITY = "31650"
HALSEY_CITY = "31750"
HAPPY_VALLEY_CITY = "32050"
HARBOR_CDP = "32100"
HARPER_CDP = "32400"
HARRISBURG_CITY = "32550"
HAYESVILLE_CDP = "32850"
HEBO_CDP = "33100"
HECETA_BEACH_CDP = "33150"
HELIX_CITY = "33250"
HEPPNER_CITY = "33550"
HERMISTON_CITY = "33700"
HILLSBORO_CITY = "34100"
HINES_CITY = "34250"
HOLLEY_CDP = "34650"
HOOD_RIVER_CITY = "34900"
HUBBARD_CITY = "35450"
HUNTINGTON_CITY = "35700"
IDANHA_CITY = "35800"
IDAVILLE_CDP = "35850"
IMBLER_CITY = "36050"
INDEPENDENCE_CITY = "36150"
IONE_CITY = "36400"
IRRIGON_CITY = "36500"
ISLAND_CITY_CITY = "36750"
JACKSONVILLE_CITY = "37000"
JASPER_CDP = "37150"
JEFFERS_GARDENS_CDP = "37202"
JEFFERSON_CITY = "37250"
JENNINGS_LODGE_CDP = "37400"
JOHN_DAY_CITY = "37550"
JOHNSON_CITY_CITY = "37650"
JORDAN_VALLEY_CITY = "37850"
JOSEPH_CITY = "37900"
JUNCTION_CITY_CITY = "38000"
JUNIPER_CANYON_CDP = "38075"
JUNTURA_CDP = "38150"
KEIZER_CITY = "38500"
KENO_CDP = "38750"
KERBY_CDP = "38900"
KING_CITY_CITY = "39150"
KINGS_VALLEY_CDP = "39350"
KIRKPATRICK_CDP = "39566"
KLAMATH_FALLS_CITY = "39700"
KNAPPA_CDP = "39850"
LA_GRANDE_CITY = "40350"
LA_PINE_CITY = "41050"
LABISH_VILLAGE_CDP = "40050"
LACOMB_CDP = "40150"
LAFAYETTE_CITY = "40300"
LAKE_OSWEGO_CITY = "40550"
LAKESIDE_CITY = "40650"
LAKEVIEW_TOWN = "40700"
LANGLOIS_CDP = "40950"
LEBANON_CITY = "41650"
LEXINGTON_TOWN = "42200"
LINCOLN_BEACH_CDP = "42550"
LINCOLN_CITY_CITY = "42600"
LONEROCK_CITY = "43400"
LONG_CREEK_CITY = "43550"
LOOKINGGLASS_CDP = "43650"
LOSTINE_CITY = "43900"
LOWELL_CITY = "44050"
LYONS_CITY = "44300"
MADRAS_CITY = "45250"
MALIN_CITY = "45400"
MANZANITA_CITY = "45700"
MAPLETON_CDP = "45750"
MARCOLA_CDP = "45850"
MARION_CDP = "45900"
MARLENE_VILLAGE_CDP = "46100"
MAUPIN_CITY = "46500"
MAYWOOD_PARK_CITY = "46730"
MCKAY_CDP = "44625"
MCMINNVILLE_CITY = "45000"
MEACHAM_CDP = "46800"
MEDFORD_CITY = "47000"
MEHAMA_CDP = "47300"
MELROSE_CDP = "47350"
MERLIN_CDP = "47650"
MERRILL_CITY = "47700"
METOLIUS_CITY = "47750"
METZGER_CDP = "47800"
MILL_CITY_CITY = "48150"
MILLERSBURG_CITY = "48300"
MILTON_FREEWATER_CITY = "48600"
MILWAUKIE_CITY = "48650"
MISSION_CDP = "49000"
MITCHELL_CITY = "49150"
MOLALLA_CITY = "49450"
MONMOUTH_CITY = "49550"
MONROE_CITY = "49600"
MONUMENT_CITY = "49750"
MORO_CITY = "50000"
MOSIER_CITY = "50050"
MOUNT_ANGEL_CITY = "50150"
MOUNT_HOOD_CDP = "50200"
MOUNT_HOOD_VILLAGES_CDP = "50236"
MOUNT_VERNON_CITY = "50250"
MULINO_CDP = "50450"
MYRTLE_CREEK_CITY = "50950"
MYRTLE_POINT_CITY = "51050"
NEAHKAHNIE_CDP = "51450"
NEHALEM_CITY = "51700"
NEOTSU_CDP = "51900"
NESIKA_BEACH_CDP = "51950"
NESKOWIN_CDP = "52000"
NETARTS_CDP = "52050"
NEW_HOPE_CDP = "52275"
NEW_PINE_CREEK_CDP = "52400"
NEWBERG_CITY = "52100"
NEWPORT_CITY = "52450"
NORTH_BEND_CITY = "53000"
NORTH_PLAINS_CITY = "53150"
NORTH_POWDER_CITY = "53300"
NYSSA_CITY = "53750"
OBRIEN_CDP = "54350"
OAK_GROVE_CDP = "53900"
OAK_HILLS_CDP = "53988"
OAKLAND_CITY = "54000"
OAKRIDGE_CITY = "54100"
OATFIELD_CDP = "54325"
OCEANSIDE_CDP = "54450"
OCHOCO_WEST_CDP = "54527"
ODELL_CDP = "54550"
ONTARIO_CITY = "54900"
OREGON_CITY_CITY = "55200"
OREGON_SHORES_CDP = "55268"
ORIENT_CDP = "55500"
PACIFIC_CITY_CDP = "56150"
PAISLEY_CITY = "56250"
PARKDALE_CDP = "56500"
PENDLETON_CITY = "57150"
PEORIA_CDP = "57300"
PHILOMATH_CITY = "57450"
PHOENIX_CITY = "57500"
PILOT_ROCK_CITY = "57650"
PINE_GROVE_CDP = "57850"
PINE_HOLLOW_CDP = "57875"
PISTOL_RIVER_CDP = "58050"
PLEASANT_VALLEY_CDP = "58500"
PLUSH_CDP = "58550"
PORT_ORFORD_CITY = "59250"
PORTLAND_CITY = "59000"
POWERS_CITY = "59600"
PRAIRIE_CITY_CITY = "59650"
PRESCOTT_CITY = "59750"
PRINEVILLE_LAKE_ACRES_CDP = "59916"
PRINEVILLE_CITY = "59850"
PRONGHORN_CDP = "60070"
PROSPECT_CDP = "60100"
RAINIER_CITY = "60850"
RALEIGH_HILLS_CDP = "60900"
REDMOND_CITY = "61200"
REDWOOD_CDP = "61250"
REEDSPORT_CITY = "61300"
RHODODENDRON_CDP = "61550"
RICHLAND_CITY = "61700"
RICKREALL_CDP = "61800"
RIDDLE_CITY = "61850"
RIVER_POINT_CDP = "62292"
RIVER_ROAD_CDP = "62300"
RIVERGROVE_CITY = "62250"
RIVERSIDE_CDP = "62412"
ROCKAWAY_BEACH_CITY = "62900"
ROCKCREEK_CDP = "63010"
ROCKY_POINT_CDP = "63250"
ROGUE_RIVER_CITY = "63450"
ROSE_LODGE_CDP = "63800"
ROSEBURG_NORTH_CDP = "63660"
ROSEBURG_CITY = "63650"
ROWENA_CDP = "63950"
RUCH_CDP = "64150"
RUFUS_CITY = "64200"
RUNNING_Y_RANCH_CDP = "64282"
SALEM_CITY = "64900"
SAN_MARINE_CDP = "65300"
SANDY_CITY = "65250"
SANTA_CLARA_CDP = "65400"
SAUNDERS_LAKE_CDP = "65450"
SCAPPOOSE_CITY = "65500"
SCIO_CITY = "65650"
SCOTTS_MILLS_CITY = "65800"
SEASIDE_CITY = "65950"
SELMA_CDP = "66150"
SENECA_CITY = "66200"
SEVENTH_MOUNTAIN_CDP = "66385"
SHADY_COVE_CITY = "66550"
SHANIKO_CITY = "66700"
SHEDD_CDP = "66900"
SHERIDAN_CITY = "67050"
SHERWOOD_CITY = "67100"
SILETZ_CITY = "67500"
SILVER_LAKE_CDP = "67600"
SILVERTON_CITY = "67650"
SISTERS_CITY = "67950"
SODAVILLE_CITY = "68550"
SOUTH_LEBANON_CDP = "68875"
SPORTSMANS_PARK_CDP = "69387"
SPRAGUE_RIVER_CDP = "69400"
SPRAY_TOWN = "69450"
SPRINGFIELD_CITY = "69600"
ST_HELENS_CITY = "64600"
ST_PAUL_CITY = "64850"
STAFFORD_CDP = "69800"
STANFIELD_CITY = "69900"
STAYTON_CITY = "70200"
SUBLIMITY_CITY = "70700"
SUMMERVILLE_TOWN = "70850"
SUMMIT_CDP = "70870"
SUMPTER_CITY = "71000"
SUNRIVER_CDP = "71250"
SUTHERLIN_CITY = "71650"
SVENSEN_CDP = "71800"
SWEET_HOME_CITY = "71950"
TAKILMA_CDP = "72400"
TALENT_CITY = "72500"
TANGENT_CITY = "72600"
TERREBONNE_CDP = "72800"
TETHEROW_CDP = "72820"
THE_DALLES_CITY = "72950"
THREE_RIVERS_CDP = "73225"
TIGARD_CITY = "73650"
TILLAMOOK_CITY = "73700"
TOLEDO_CITY = "74000"
TRAIL_CDP = "74400"
TRENT_CDP = "74550"
TRI_CITY_CDP = "74650"
TROUTDALE_CITY = "74850"
TUALATIN_CITY = "74950"
TUMALO_CDP = "75050"
TURNER_CITY = "75150"
TUTUILLA_CDP = "75185"
TYGH_VALLEY_CDP = "75500"
UKIAH_CITY = "75550"
UMAPINE_CDP = "75600"
UMATILLA_CITY = "75650"
UNION_CITY = "75850"
UNITY_CITY = "76250"
VALE_CITY = "76600"
VENETA_CITY = "77050"
VERNONIA_CITY = "77250"
WALDPORT_CITY = "78000"
WALLOWA_LAKE_CDP = "78160"
WALLOWA_CITY = "78150"
WAMIC_CDP = "78300"
WARM_SPRINGS_CDP = "78600"
WARREN_CDP = "78800"
WARRENTON_CITY = "78900"
WASCO_CITY = "78950"
WATERLOO_TOWN = "79050"
WEDDERBURN_CDP = "79500"
WEST_HAVEN_SYLVAN_CDP = "80025"
WEST_LINN_CITY = "80150"
WEST_SCIO_CDP = "80750"
WEST_SLOPE_CDP = "80900"
WESTFIR_CITY = "79950"
WESTON_CITY = "80350"
WESTPORT_CDP = "80400"
WHEELER_CITY = "81300"
WHITE_CITY_CDP = "81450"
WILLAMINA_CITY = "82350"
WILLIAMS_CDP = "82450"
WILSONVILLE_CITY = "82800"
WIMER_CDP = "82850"
WINCHESTER_BAY_CDP = "83050"
WINSTON_CITY = "83400"
WOOD_VILLAGE_CITY = "83950"
WOODBURN_CITY = "83750"
YACHATS_CITY = "84200"
YAMHILL_CITY = "84250"
YONCALLA_CITY = "84600"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Maryland."""


ABERDEEN_PROVING_GROUND_CDP = "00175"
ABERDEEN_CITY = "00125"
ABINGDON_CDP = "00200"
ACCIDENT_TOWN = "00225"
ACCOKEEK_CDP = "00250"
ADAMSTOWN_CDP = "00350"
ADELPHI_CDP = "00400"
ALGONQUIN_CDP = "00712"
ALLEN_CDP = "00800"
ANDREWS_AFB_CDP = "01450"
ANNAPOLIS_NECK_CDP = "01635"
ANNAPOLIS_CITY = "01600"
ANTIETAM_CDP = "01750"
AQUASCO_CDP = "01925"
ARBUTUS_CDP = "01975"
ARDEN_ON_THE_SEVERN_CDP = "02025"
ARNOLD_CDP = "02275"
ASHTON_SANDY_SPRING_CDP = "02762"
ASPEN_HILL_CDP = "02825"
BADEN_CDP = "03500"
BAGTOWN_CDP = "03514"
BAKERSVILLE_CDP = "03575"
BALLENGER_CREEK_CDP = "03800"
BALTIMORE_HIGHLANDS_CDP = "04050"
BALTIMORE_CITY = "04000"
BARCLAY_TOWN = "04250"
BARNESVILLE_TOWN = "04475"
BARRELVILLE_CDP = "04525"
BARTON_TOWN = "04625"
BARTONSVILLE_CDP = "04650"
BEAVER_CREEK_CDP = "05250"
BEL_AIR_CDP = "05525"
BEL_AIR_NORTH_CDP = "05825"
BEL_AIR_SOUTH_CDP = "05950"
BEL_AIR_TOWN = "05550"
BELTSVILLE_CDP = "06400"
BENEDICT_CDP = "06550"
BENSVILLE_CDP = "06662"
BERLIN_TOWN = "06800"
BERWYN_HEIGHTS_TOWN = "06925"
BETHESDA_CDP = "07125"
BETTERTON_TOWN = "07200"
BIER_CDP = "07285"
BIG_POOL_CDP = "07375"
BIG_SPRING_CDP = "07400"
BISHOPVILLE_CDP = "07625"
BIVALVE_CDP = "07675"
BLADENSBURG_TOWN = "07850"
BLOOMINGTON_CDP = "08050"
BOONSBORO_TOWN = "08625"
BOWIE_CITY = "08775"
BOWLEYS_QUARTERS_CDP = "08800"
BOWLING_GREEN_CDP = "08850"
BOWMANS_ADDITION_CDP = "08862"
BRADDOCK_HEIGHTS_CDP = "09100"
BRANDYWINE_CDP = "09325"
BREATHEDSVILLE_CDP = "09400"
BRENTWOOD_TOWN = "09500"
BROCK_HALL_CDP = "10150"
BROOKEVILLE_TOWN = "10225"
BROOKLYN_PARK_CDP = "10475"
BROOKMONT_CDP = "10500"
BROOKVIEW_TOWN = "10575"
BROOMES_ISLAND_CDP = "10650"
BROWN_STATION_CDP = "10737"
BROWNSVILLE_CDP = "10800"
BRUNSWICK_CITY = "10900"
BRYANS_ROAD_CDP = "10925"
BRYANTOWN_CDP = "10950"
BUCKEYSTOWN_CDP = "11050"
BURKITTSVILLE_TOWN = "11400"
BURNT_MILLS_CDP = "11550"
BURTONSVILLE_CDP = "11750"
BUTLERTOWN_CDP = "11900"
CABIN_JOHN_CDP = "12075"
CALIFORNIA_CDP = "12150"
CALLAWAY_CDP = "12175"
CALVERT_BEACH_CDP = "12300"
CALVERTON_CDP = "12350"
CAMBRIDGE_CITY = "12400"
CAMP_SPRINGS_CDP = "12600"
CAPE_ST_CLAIRE_CDP = "12912"
CAPITOL_HEIGHTS_TOWN = "13000"
CARLOS_CDP = "13225"
CARNEY_CDP = "13325"
CATONSVILLE_CDP = "14125"
CAVETOWN_CDP = "14225"
CEARFOSS_CDP = "14300"
CECILTON_TOWN = "14325"
CEDAR_HEIGHTS_CDP = "14550"
CEDARVILLE_CDP = "14800"
CENTREVILLE_TOWN = "14950"
CHANCE_CDP = "15075"
CHARLESTOWN_TOWN = "15400"
CHARLOTTE_HALL_CDP = "15475"
CHARLTON_CDP = "15500"
CHESAPEAKE_BEACH_TOWN = "15925"
CHESAPEAKE_CITY_TOWN = "15950"
CHESAPEAKE_LANDING_CDP = "16025"
CHESAPEAKE_RANCH_ESTATES_CDP = "16050"
CHESTER_CDP = "16125"
CHESTERTOWN_TOWN = "16225"
CHEVERLY_TOWN = "16550"
CHEVY_CHASE_CDP = "16625"
CHEVY_CHASE_SECTION_FIVE_VILLAGE = "16720"
CHEVY_CHASE_SECTION_THREE_VILLAGE = "16730"
CHEVY_CHASE_VIEW_TOWN = "16775"
CHEVY_CHASE_VILLAGE_TOWN = "16787"
CHEVY_CHASE_TOWN = "16620"
CHEWSVILLE_CDP = "16800"
CHILLUM_CDP = "16875"
CHOPTANK_CDP = "17000"
CHURCH_CREEK_TOWN = "17050"
CHURCH_HILL_TOWN = "17100"
CLARKSBURG_CDP = "17350"
CLARYSVILLE_CDP = "17475"
CLEAR_SPRING_TOWN = "17600"
CLINTON_CDP = "17900"
CLOVERLY_CDP = "18150"
COBB_ISLAND_CDP = "18200"
COCKEYSVILLE_CDP = "18250"
COLESVILLE_CDP = "18475"
COLLEGE_PARK_CITY = "18750"
COLMAR_MANOR_TOWN = "18850"
COLUMBIA_CDP = "19125"
CORAL_HILLS_CDP = "19825"
CORDOVA_CDP = "19900"
CORRIGANVILLE_CDP = "19975"
COTTAGE_CITY_TOWN = "20050"
CRELLIN_CDP = "20500"
CRESAPTOWN_CDP = "20525"
CRISFIELD_CITY = "20775"
CROFTON_CDP = "20875"
CROOM_CDP = "20925"
CROWNSVILLE_CDP = "21075"
CRUMPTON_CDP = "21150"
CUMBERLAND_CITY = "21325"
DAMASCUS_CDP = "21475"
DAMES_QUARTER_CDP = "21550"
DANVILLE_CDP = "21675"
DARGAN_CDP = "21750"
DARLINGTON_CDP = "21800"
DARNESTOWN_CDP = "21825"
DAWSON_CDP = "21925"
DEAL_ISLAND_CDP = "22100"
DEALE_CDP = "22050"
DEER_PARK_TOWN = "22275"
DELMAR_TOWN = "22600"
DENTON_TOWN = "22725"
DERWOOD_CDP = "22775"
DETMOLD_CDP = "22825"
DISTRICT_HEIGHTS_CITY = "23025"
DOWNSVILLE_CDP = "23500"
DRUM_POINT_CDP = "23700"
DUNDALK_CDP = "23975"
DUNKIRK_CDP = "24050"
EAGLE_HARBOR_TOWN = "24200"
EAKLES_MILL_CDP = "24250"
EAST_NEW_MARKET_TOWN = "24450"
EAST_RIVERDALE_CDP = "24650"
EASTON_TOWN = "24475"
ECKHART_MINES_CDP = "24825"
EDEN_CDP = "24850"
EDESVILLE_CDP = "24925"
EDGEMERE_CDP = "24950"
EDGEMONT_CDP = "25000"
EDGEWATER_CDP = "25050"
EDGEWOOD_CDP = "25150"
EDMONSTON_TOWN = "25425"
ELDERSBURG_CDP = "25575"
ELDORADO_TOWN = "25600"
ELKRIDGE_CDP = "25750"
ELKTON_TOWN = "25800"
ELLERSLIE_CDP = "25925"
ELLICOTT_CITY_CDP = "26000"
ELLIOTT_CDP = "26025"
EMMITSBURG_TOWN = "26200"
ERNSTVILLE_CDP = "26550"
ESSEX_CDP = "26600"
FAIRLAND_CDP = "27250"
FAIRLEE_CDP = "27325"
FAIRMOUNT_CDP = "27375"
FAIRMOUNT_HEIGHTS_TOWN = "27400"
FAIRPLAY_CDP = "27425"
FAIRVIEW_CDP = "27500"
FAIRWOOD_CDP = "27580"
FALLSTON_CDP = "27700"
FEDERALSBURG_TOWN = "27900"
FERNDALE_CDP = "28075"
FINZEL_CDP = "28275"
FISHING_CREEK_CDP = "28300"
FLINTSTONE_CDP = "28425"
FLOWER_HILL_CDP = "28512"
FOREST_GLEN_CDP = "28640"
FOREST_HEIGHTS_TOWN = "28725"
FORESTVILLE_CDP = "29000"
FORT_MEADE_CDP = "29400"
FORT_RITCHIE_CDP = "29450"
FORT_WASHINGTON_CDP = "29525"
FOUNTAINHEAD_ORCHARD_HILLS_CDP = "29712"
FOUR_CORNERS_CDP = "29790"
FRANKLIN_CDP = "30100"
FREDERICK_CITY = "30325"
FRENCHTOWN_RUMBLY_CDP = "30567"
FRIENDLY_CDP = "30575"
FRIENDSHIP_CDP = "30650"
FRIENDSHIP_HEIGHTS_VILLAGE_CDP = "30800"
FRIENDSVILLE_TOWN = "30850"
FROSTBURG_CITY = "30900"
FRUITLAND_CITY = "30950"
FULTON_CDP = "31025"
FUNKSTOWN_TOWN = "31100"
GAITHERSBURG_CITY = "31175"
GALENA_TOWN = "31225"
GALESTOWN_TOWN = "31250"
GALESVILLE_CDP = "31275"
GAMBRILLS_CDP = "31350"
GAPLAND_CDP = "31400"
GARRETT_PARK_TOWN = "31525"
GARRETTS_MILL_CDP = "31575"
GARRISON_CDP = "31625"
GEORGETOWN_CDP = "31875"
GERMANTOWN_CDP = "32025"
GILMORE_CDP = "32175"
GIRDLETREE_CDP = "32250"
GLASSMANOR_CDP = "32350"
GLEN_BURNIE_CDP = "32650"
GLEN_ECHO_TOWN = "32900"
GLENARDEN_CITY = "32500"
GLENMONT_CDP = "33250"
GLENN_DALE_CDP = "33400"
GOLDEN_BEACH_CDP = "33850"
GOLDSBORO_TOWN = "33950"
GORMAN_CDP = "34150"
GRACEHAM_CDP = "34350"
GRAHAMTOWN_CDP = "34425"
GRANTSVILLE_TOWN = "34525"
GRASONVILLE_CDP = "34550"
GREEN_VALLEY_CDP = "35412"
GREENBELT_CITY = "34775"
GREENSBORO_TOWN = "35200"
GREENSBURG_CDP = "35225"
HAGERSTOWN_CITY = "36075"
HALFWAY_CDP = "36125"
HAMPSTEAD_TOWN = "36500"
HAMPTON_CDP = "36512"
HANCOCK_TOWN = "36600"
HAVRE_DE_GRACE_CITY = "37600"
HEBRON_TOWN = "37875"
HENDERSON_TOWN = "37925"
HERALD_HARBOR_CDP = "38025"
HIGHFIELD_CASCADE_CDP = "38437"
HIGHLAND_BEACH_TOWN = "38500"
HIGHLAND_CDP = "38475"
HILLANDALE_CDP = "38850"
HILLCREST_HEIGHTS_CDP = "38975"
HILLSBORO_TOWN = "39175"
HONEYGO_CDP = "40200"
HUGHESVILLE_CDP = "40700"
HUNTINGTOWN_CDP = "41025"
HURLOCK_TOWN = "41125"
HUTTON_CDP = "41175"
HYATTSVILLE_CITY = "41250"
ILCHESTER_CDP = "41475"
INDIAN_HEAD_TOWN = "41500"
INDIAN_SPRINGS_CDP = "41700"
JARRETTSVILLE_CDP = "42325"
JEFFERSON_CDP = "42350"
JENNINGS_CDP = "42450"
JESSUP_CDP = "42550"
JESTERVILLE_CDP = "42575"
JOPPATOWNE_CDP = "42875"
JUGTOWN_CDP = "42950"
KEEDYSVILLE_TOWN = "43100"
KEMP_MILL_CDP = "43200"
KEMPS_MILL_CDP = "43280"
KENNEDYVILLE_CDP = "43475"
KENSINGTON_TOWN = "43500"
KENT_NARROWS_CDP = "43725"
KETTERING_CDP = "43900"
KINGSTOWN_CDP = "44325"
KINGSVILLE_CDP = "44350"
KITZMILLER_TOWN = "44450"
KLONDIKE_CDP = "44525"
KONTERRA_CDP = "44715"
LA_PLATA_TOWN = "45750"
LA_VALE_CDP = "46075"
LAKE_ARBOR_CDP = "44817"
LAKE_SHORE_CDP = "44975"
LANDOVER_CDP = "45325"
LANDOVER_HILLS_TOWN = "45400"
LANGLEY_PARK_CDP = "45525"
LANHAM_CDP = "45550"
LANSDOWNE_CDP = "45650"
LARGO_CDP = "45825"
LAUREL_CITY = "45900"
LAYHILL_CDP = "46150"
LAYTONSVILLE_TOWN = "46250"
LEISURE_WORLD_CDP = "46375"
LEITERSBURG_CDP = "46400"
LEONARDTOWN_TOWN = "46475"
LEWISTOWN_CDP = "46650"
LEXINGTON_PARK_CDP = "46725"
LIBERTYTOWN_CDP = "46800"
LINGANORE_CDP = "47040"
LINTHICUM_CDP = "47125"
LISBON_CDP = "47250"
LITTLE_ORLEANS_CDP = "47275"
LOCH_LYNN_HEIGHTS_TOWN = "47525"
LOCHEARN_CDP = "47450"
LONACONING_TOWN = "47875"
LONG_BEACH_CDP = "48025"
LUKE_TOWN = "48775"
LUSBY_CDP = "48800"
LUTHERVILLE_CDP = "48875"
MADISON_CDP = "49700"
MANCHESTER_TOWN = "49950"
MAPLEVILLE_CDP = "50375"
MARDELA_SPRINGS_TOWN = "50525"
MARLBORO_MEADOWS_CDP = "50680"
MARLBORO_VILLAGE_CDP = "50685"
MARLOW_HEIGHTS_CDP = "50750"
MARLTON_CDP = "50775"
MARTINS_ADDITIONS_VILLAGE = "50965"
MARYDEL_TOWN = "51025"
MARYLAND_CITY_CDP = "51075"
MARYLAND_PARK_CDP = "51125"
MAUGANSVILLE_CDP = "51425"
MAYO_CDP = "51575"
MAYS_CHAPEL_CDP = "51587"
MCCOOLE_CDP = "49325"
MECHANICSVILLE_CDP = "51800"
MELWOOD_CDP = "51940"
MERCERSVILLE_CDP = "51945"
MIDDLE_RIVER_CDP = "52300"
MIDDLEBURG_CDP = "52225"
MIDDLETOWN_TOWN = "52425"
MIDLAND_TOWN = "52475"
MIDLOTHIAN_CDP = "52525"
MILFORD_MILL_CDP = "52562"
MILLINGTON_TOWN = "52825"
MITCHELLVILLE_CDP = "52975"
MONROVIA_CDP = "53100"
MONTGOMERY_VILLAGE_CDP = "53325"
MORNINGSIDE_TOWN = "53625"
MOSCOW_CDP = "53700"
MOUNT_AETNA_CDP = "53750"
MOUNT_AIRY_TOWN = "53875"
MOUNT_BRIAR_CDP = "53925"
MOUNT_LENA_CDP = "54125"
MOUNT_RAINIER_CITY = "54275"
MOUNT_SAVAGE_CDP = "54325"
MOUNT_VERNON_CDP = "54375"
MOUNTAIN_LAKE_PARK_TOWN = "53800"
MYERSVILLE_TOWN = "54875"
NANTICOKE_ACRES_CDP = "54930"
NANTICOKE_CDP = "54925"
NATIONAL_CDP = "55000"
NATIONAL_HARBOR_CDP = "55018"
NAVAL_ACADEMY_CDP = "55050"
NEW_CARROLLTON_CITY = "55400"
NEW_MARKET_TOWN = "55650"
NEW_WINDSOR_TOWN = "55925"
NEWARK_CDP = "55325"
NIKEP_CDP = "55950"
NORTH_BEACH_TOWN = "56300"
NORTH_BETHESDA_CDP = "56337"
NORTH_BRENTWOOD_TOWN = "56375"
NORTH_CHEVY_CHASE_VILLAGE = "56400"
NORTH_EAST_TOWN = "56450"
NORTH_KENSINGTON_CDP = "56712"
NORTH_LAUREL_CDP = "56725"
NORTH_POTOMAC_CDP = "56875"
OAKLAND_TOWN = "57650"
OCEAN_CDP = "58215"
OCEAN_CITY_TOWN = "58225"
OCEAN_PINES_CDP = "58275"
ODENTON_CDP = "58300"
OLDTOWN_CDP = "58775"
OLNEY_CDP = "58900"
OVERLEA_CDP = "59325"
OWINGS_CDP = "59375"
OWINGS_MILLS_CDP = "59425"
OXFORD_TOWN = "59450"
OXON_HILL_CDP = "59500"
PARAMOUNT_LONG_MEADOW_CDP = "59787"
PARKVILLE_CDP = "60275"
PAROLE_CDP = "60325"
PARSONSBURG_CDP = "60425"
PASADENA_CDP = "60475"
PECKTONVILLE_CDP = "60770"
PEPPERMILL_VILLAGE_CDP = "60950"
PERRY_HALL_CDP = "60975"
PERRYMAN_CDP = "61075"
PERRYVILLE_TOWN = "61150"
PIKESVILLE_CDP = "61400"
PINESBURG_CDP = "61700"
PINEY_POINT_CDP = "61875"
PITTSVILLE_TOWN = "62025"
PLEASANT_GROVE_CDP = "62100"
PLEASANT_HILLS_CDP = "62175"
POCOMOKE_CITY_CITY = "62475"
POINT_OF_ROCKS_CDP = "62575"
POMFRET_CDP = "62675"
PONDSVILLE_CDP = "62775"
POOLESVILLE_TOWN = "62850"
PORT_DEPOSIT_TOWN = "63075"
PORT_TOBACCO_VILLAGE_TOWN = "63225"
POTOMAC_CDP = "63300"
POTOMAC_HEIGHTS_CDP = "63375"
POTOMAC_PARK_CDP = "63425"
POWELLVILLE_CDP = "63725"
PRESTON_TOWN = "63825"
PRINCE_FREDERICK_CDP = "63950"
PRINCESS_ANNE_TOWN = "64000"
PYLESVILLE_CDP = "64375"
QUANTICO_CDP = "64475"
QUEEN_ANNE_CDP = "64495"
QUEEN_ANNE_TOWN = "64500"
QUEENSLAND_CDP = "64568"
QUEENSTOWN_TOWN = "64600"
RANDALLSTOWN_CDP = "64950"
RAWLINGS_CDP = "65150"
REDLAND_CDP = "65312"
REID_CDP = "65550"
REISTERSTOWN_CDP = "65600"
RIDGELY_TOWN = "66000"
RINGGOLD_CDP = "66150"
RISING_SUN_TOWN = "66275"
RIVA_CDP = "66400"
RIVERDALE_PARK_TOWN = "66635"
RIVERSIDE_CDP = "66762"
RIVIERA_BEACH_CDP = "66850"
ROBINWOOD_CDP = "67000"
ROCK_HALL_TOWN = "67400"
ROCK_POINT_CDP = "67500"
ROCKVILLE_CITY = "67675"
ROHRERSVILLE_CDP = "67950"
ROMANCOKE_CDP = "68265"
ROSARYVILLE_CDP = "68300"
ROSEDALE_CDP = "68400"
ROSEMONT_VILLAGE = "68600"
ROSSVILLE_CDP = "68700"
SABILLASVILLE_CDP = "69200"
SALISBURY_CITY = "69925"
SAN_MAR_CDP = "70300"
SANDY_HOOK_CDP = "70175"
SAVAGE_CDP = "70475"
SCAGGSVILLE_CDP = "70525"
SEABROOK_CDP = "70775"
SEAT_PLEASANT_CITY = "70850"
SECRETARY_TOWN = "70900"
SEVERN_CDP = "71150"
SEVERNA_PARK_CDP = "71200"
SHADY_SIDE_CDP = "71450"
SHAFT_CDP = "71460"
SHARPSBURG_TOWN = "71600"
SHARPTOWN_TOWN = "71650"
SILVER_HILL_CDP = "72350"
SILVER_SPRING_CDP = "72450"
SMITH_ISLAND_CDP = "72887"
SMITHSBURG_TOWN = "72900"
SNOW_HILL_TOWN = "73075"
SOLOMONS_CDP = "73325"
SOMERSET_TOWN = "73350"
SOUTH_KENSINGTON_CDP = "73600"
SOUTH_LAUREL_CDP = "73650"
SPENCERVILLE_CDP = "74050"
SPRING_GAP_CDP = "74350"
SPRING_RIDGE_CDP = "74560"
SPRINGDALE_CDP = "74282"
ST_GEORGE_ISLAND_CDP = "69425"
ST_JAMES_CDP = "69550"
ST_LEONARD_CDP = "69675"
ST_MICHAELS_TOWN = "69825"
STEVENSVILLE_CDP = "75025"
STILL_POND_CDP = "75150"
STOCKTON_CDP = "75200"
SUDLERSVILLE_TOWN = "75650"
SUITLAND_CDP = "75725"
SUMMERFIELD_CDP = "75810"
SWANTON_CDP = "76450"
SYKESVILLE_TOWN = "76550"
TAKOMA_PARK_CITY = "76650"
TALL_TIMBERS_CDP = "76675"
TANEYTOWN_CITY = "76725"
TAYLORS_ISLAND_CDP = "76925"
TEMPLE_HILLS_CDP = "77100"
TEMPLEVILLE_TOWN = "77200"
TEN_MILE_CREEK_CDP = "77262"
THURMONT_TOWN = "77825"
TILGHMAN_ISLAND_CDP = "77912"
TILGHMANTON_CDP = "77925"
TIMONIUM_CDP = "78050"
TOLCHESTER_CDP = "78120"
TOWSON_CDP = "78425"
TRAPPE_TOWN = "78575"
TRAVILAH_CDP = "78650"
TREGO_ROHRERSVILLE_STATION_CDP = "78705"
TYASKIN_CDP = "79225"
UNION_BRIDGE_TOWN = "79350"
UNIVERSITY_PARK_TOWN = "79675"
UPPER_MARLBORO_TOWN = "79875"
URBANA_CDP = "79900"
VALE_SUMMIT_CDP = "80075"
VIENNA_TOWN = "80600"
WALDORF_CDP = "81175"
WALKER_MILL_CDP = "81250"
WALKERSVILLE_TOWN = "81275"
WASHINGTON_GROVE_TOWN = "81675"
WATERVIEW_CDP = "81925"
WEST_DENTON_CDP = "82625"
WEST_LAUREL_CDP = "83025"
WEST_OCEAN_CITY_CDP = "83225"
WEST_POCOMOKE_CDP = "83337"
WESTERNPORT_TOWN = "82750"
WESTMINSTER_CITY = "83100"
WESTPHALIA_CDP = "83290"
WHALEYVILLE_CDP = "83746"
WHEATON_CDP = "83775"
WHITE_MARSH_CDP = "84350"
WHITE_OAK_CDP = "84375"
WHITEHAVEN_CDP = "84225"
WILDEWOOD_CDP = "84784"
WILLARDS_TOWN = "84950"
WILLIAMSPORT_TOWN = "85100"
WILLISTON_CDP = "85175"
WILSON_CONOCOCHEAGUE_CDP = "85395"
WOODLAND_CDP = "86275"
WOODLAWN_CDP_BALTIMORE_COUNTY = "86475"
WOODLAWN_CDP_PRINCE_GEORGES_COUNTY = "86525"
WOODMORE_CDP = "86710"
WOODSBORO_TOWN = "86750"
WORTON_CDP = "87000"
YARROWSBURG_CDP = "87150"
ZIHLMAN_CDP = "87275"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Kentucky."""


ADAIR = "001"
ALLEN = "003"
ANDERSON = "005"
BALLARD = "007"
BARREN = "009"
BATH = "011"
BELL = "013"
BOONE = "015"
BOURBON = "017"
BOYD = "019"
BOYLE = "021"
BRACKEN = "023"
BREATHITT = "025"
BRECKINRIDGE = "027"
BULLITT = "029"
BUTLER = "031"
CALDWELL = "033"
CALLOWAY = "035"
CAMPBELL = "037"
CARLISLE = "039"
CARROLL = "041"
CARTER = "043"
CASEY = "045"
CHRISTIAN = "047"
CLARK = "049"
CLAY = "051"
CLINTON = "053"
CRITTENDEN = "055"
CUMBERLAND = "057"
DAVIESS = "059"
EDMONSON = "061"
ELLIOTT = "063"
ESTILL = "065"
FAYETTE = "067"
FLEMING = "069"
FLOYD = "071"
FRANKLIN = "073"
FULTON = "075"
GALLATIN = "077"
GARRARD = "079"
GRANT = "081"
GRAVES = "083"
GRAYSON = "085"
GREEN = "087"
GREENUP = "089"
HANCOCK = "091"
HARDIN = "093"
HARLAN = "095"
HARRISON = "097"
HART = "099"
HENDERSON = "101"
HENRY = "103"
HICKMAN = "105"
HOPKINS = "107"
JACKSON = "109"
JEFFERSON = "111"
JESSAMINE = "113"
JOHNSON = "115"
KENTON = "117"
KNOTT = "119"
KNOX = "121"
LARUE = "123"
LAUREL = "125"
LAWRENCE = "127"
LEE = "129"
LESLIE = "131"
LETCHER = "133"
LEWIS = "135"
LINCOLN = "137"
LIVINGSTON = "139"
LOGAN = "141"
LYON = "143"
MADISON = "151"
MAGOFFIN = "153"
MARION = "155"
MARSHALL = "157"
MARTIN = "159"
MASON = "161"
MCCRACKEN = "145"
MCCREARY = "147"
MCLEAN = "149"
MEADE = "163"
MENIFEE = "165"
MERCER = "167"
METCALFE = "169"
MONROE = "171"
MONTGOMERY = "173"
MORGAN = "175"
MUHLENBERG = "177"
NELSON = "179"
NICHOLAS = "181"
OHIO = "183"
OLDHAM = "185"
OWEN = "187"
OWSLEY = "189"
PENDLETON = "191"
PERRY = "193"
PIKE = "195"
POWELL = "197"
PULASKI = "199"
ROBERTSON = "201"
ROCKCASTLE = "203"
ROWAN = "205"
RUSSELL = "207"
SCOTT = "209"
SHELBY = "211"
SIMPSON = "213"
SPENCER = "215"
TAYLOR = "217"
TODD = "219"
TRIGG = "221"
TRIMBLE = "223"
UNION = "225"
WARREN = "227"
WASHINGTON = "229"
WAYNE = "231"
WEBSTER = "233"
WHITLEY = "235"
WOLFE = "237"
WOODFORD = "239"
